      MODULE biology_mod
!
!svn $Id: biology.F 363 2009-07-07 20:54:53Z arango $
!================================================== Hernan G. Arango ===
!  Copyright (c) 2002-2009 The ROMS/TOMS Group                         !
!    Licensed under a MIT/X style license                              !
!    See License_ROMS.txt                                              !
!=======================================================================
!                                                                      !
!  This routine computes the source and sink terms for selected        !
!   biology model.                                                     !
!                                                                      !
!=======================================================================
!
      implicit none
      PRIVATE
      PUBLIC  :: biology
      CONTAINS
      SUBROUTINE biology (ng,tile)
!
!svn $Id: darwin.h 294 2009-01-09 21:37:26Z arango $
!********************************************* Christopher A. Edwards***
!***********************************************  Nicole L. Goebel   ***
!  Copyright (c) 2002-2009 The ROMS/TOMS Group                         !
!    Licensed under a MIT/X style license                              !
!    See License_ROMS.txt                                              !
!***********************************************************************
!                                                                      !
!  Driver for the DARWIN model.                                        !
!                                                                      !
!  This routine computes the biological sources and sinks and adds     !
!  then the global biological fields.                                  !
!                                                                      !
!***********************************************************************
!
      USE mod_param
      USE mod_diags
      USE mod_forces
      USE mod_grid
      USE mod_ncparam
      USE mod_ocean
      USE mod_stepping
      USE mod_biology
!
!  Imported variable declarations.
!
      integer, intent(in) :: ng, tile
!
!  Local variable declarations.
!
      integer :: IminS, ImaxS, JminS, JmaxS
      integer :: LBi, UBi, LBj, UBj, LBij, UBij
!
!  Set horizontal starting and ending indices for automatic private storage
!  arrays.
!
      IminS=BOUNDS(ng)%Istr(tile)-3
      ImaxS=BOUNDS(ng)%Iend(tile)+3
      JminS=BOUNDS(ng)%Jstr(tile)-3
      JmaxS=BOUNDS(ng)%Jend(tile)+3
!
!  Determine array lower and upper bounds in the I- and J-directions.
!
      LBi=BOUNDS(ng)%LBi(tile)
      UBi=BOUNDS(ng)%UBi(tile)
      LBj=BOUNDS(ng)%LBj(tile)
      UBj=BOUNDS(ng)%UBj(tile)
!
!  Set array lower and upper bounds for MIN(I,J)- and MAX(I,J)-directions.
!
      LBij=BOUNDS(ng)%LBij
      UBij=BOUNDS(ng)%UBij
!
!  Set header file name.
!
      IF (Lbiofile(iNLM)) THEN
        Lbiofile(iNLM)=.FALSE.
        BIONAME(iNLM)="/home/ngoebel/darwin/darwin_20110408/Functionals/darwin.h"
      END IF
!
      CALL wclock_on (ng, iNLM, 15)
      CALL biology_tile (ng, tile,                                      &
     &                   LBi, UBi, LBj, UBj, N(ng), NT(ng),             &
     &                   IminS, ImaxS, JminS, JmaxS,                    &
     &                   nstp(ng), nnew(ng),                            &
     &                   GRID(ng) % rmask,                              &
     &                   GRID(ng) % Hz,                                 &
     &                   GRID(ng) % z_r,                                &
     &                   GRID(ng) % z_w,                                &
     &                   FORCES(ng) % srflx,                            &
     &                   DIAGS(ng) % DiaBio2d,                          &
     &                   DIAGS(ng) % DiaBio3d,                          &
     &                   OCEAN(ng) % t)
      CALL wclock_off (ng, iNLM, 15)
      RETURN
      END SUBROUTINE biology
!
!-----------------------------------------------------------------------
      SUBROUTINE biology_tile (ng, tile,                                &
     &                         LBi, UBi, LBj, UBj, UBk, UBt,            &
     &                         IminS, ImaxS, JminS, JmaxS,              &
     &                         nstp, nnew,                              &
     &                         rmask,                                   &
     &                         Hz, z_r, z_w,                            &
     &                         srflx,                                   &
     &                         DiaBio2d, DiaBio3d,                      &
     &                         t)
!-----------------------------------------------------------------------
!
      USE mod_param
      USE mod_biology
      USE mod_ncparam
      USE mod_scalars
      USE distribute_mod, ONLY : mp_reduce, mp_bcasti
      USE mod_iounits
      USE mod_parallel
      USE darwin_plankton_mod, only : darwin_plankton
      USE darwin_random_mod
!
!  Imported variable declarations.
!
      integer, intent(in) :: ng, tile
      integer, intent(in) :: LBi, UBi, LBj, UBj, UBk, UBt
      integer, intent(in) :: IminS, ImaxS, JminS, JmaxS
      integer, intent(in) :: nstp, nnew
      real(r8), intent(in) :: rmask(LBi:,LBj:)
      real(r8), intent(in) :: Hz(LBi:,LBj:,:)
      real(r8), intent(in) :: z_r(LBi:,LBj:,:)
      real(r8), intent(in) :: z_w(LBi:,LBj:,0:)
      real(r8), intent(in) :: srflx(LBi:,LBj:)
      real(r8), intent(inout) :: DiaBio2d(LBi:,LBj:,:)
      real(r8), intent(inout) :: DiaBio3d(LBi:,LBj:,:,:)
      real(r8), intent(inout) :: t(LBi:,LBj:,:,:,:)
!
!  Local variable declarations.
!
      real(r8), dimension(npmax) :: buffer
      integer :: Nreduce
      character (len=3), dimension(npmax) :: op_handle
      integer, parameter :: Nsink = 2
      integer :: Iter, ibio, isink, itime, itrc, iTrcMax
      integer :: i, j, k, ks
      integer, dimension(Nsink) :: idsink
      real(r8), parameter :: MinVal = 1.0e-14_r8
      real(r8) :: Att, PAR
      real(r8) :: cff, dtdays, dtsecs
      real(r8) :: cffL, cffR, cu, dltL, dltR
      real(r8), dimension(Nsink) :: Wbio
      integer, dimension(IminS:ImaxS,N(ng)) :: ksource
      real(r8), dimension(IminS:ImaxS) :: PARsur
      real(r8), dimension(NT(ng),2) :: BioTrc
      real(r8), dimension(IminS:ImaxS,N(ng),NT(ng)) :: Bio
      real(r8), dimension(IminS:ImaxS,N(ng),NT(ng)) :: Bio_bak
      real(r8), dimension(IminS:ImaxS,N(ng)) :: Hz_inv
      real(r8), dimension(IminS:ImaxS,N(ng)) :: Light
      integer :: kk, kp1, MyThid, np, ktmp, ip
      real(r8) sumpy, lig, FeL
      integer :: ivar
      real(r8) :: DiaBio2dLocal(NDbio2d)
      real(r8) :: DiaBio3dLocal(NDbio3d)
      real(r8) dummy
! === GLOBAL VARIABLES =====================
! npmax = no of phyto functional groups
! nzmax = no of grazer species
! phyto = phytoplankton
! zoo   = zooplankton
         real(r8) phyto(npmax)
         real(r8) zooP(nzmax)
         real(r8) zooN(nzmax)
         real(r8) zooSi(nzmax)
         real(r8) PO4local
         real(r8) NO3local
         real(r8) Silocal
         real(r8) NO2local
         real(r8) NH4local
         real(r8) DOPlocal
         real(r8) DONlocal
         real(r8) POPlocal
         real(r8) PONlocal
         real(r8) PSilocal
         real(r8) PARlocal
         real(r8) Tlocal
         real(r8) Slocal
         real(r8) dzlocal,dummyt,dummyb,dummyt0, dummyt1, dummyt00
         INTEGER debug
         real(r8) :: flux_top (LBi:UBi,NT(ng)), flux_bot(LBi:UBi,NT(ng))
         real(r8) :: delta (LBi:UBi,NT(ng))
         real(r8) prePOP,prePOPdelta,prePOPfluxbot,corrPOP,corrPOPfluxbot
         real(r8) corrPOPdelta,aftPOPupdate,aftPOPfluxtop,aftPOP
         real(r8) aftPOPdelta, aftPOPfluxbot,aftPOPfluxdelta,flux_topPOPorig
         real(r8) ptot0,ptot1,ptot2,ptot0sum, ptot1sum,ptot2sum,ptot1sumcae
         real(r8),dimension(30):: ptotcae
         REAL arr(npmax)
         INTEGER irank(npmax), indx(npmax)
         logical error
!
!-----------------------------------------------------------------------
!  Set lower and upper tile bounds and staggered variables bounds for
!  this horizontal domain partition.  Notice that if tile=-1, it will
!  set the values for the global grid.
!-----------------------------------------------------------------------
!
      integer :: Istr, IstrR, IstrT, IstrU, Iend, IendR, IendT
      integer :: Jstr, JstrR, JstrT, JstrV, Jend, JendR, JendT
!
      Istr =BOUNDS(ng)%Istr (tile)
      IstrR=BOUNDS(ng)%IstrR(tile)
      IstrT=BOUNDS(ng)%IstrT(tile)
      IstrU=BOUNDS(ng)%IstrU(tile)
      Iend =BOUNDS(ng)%Iend (tile)
      IendR=BOUNDS(ng)%IendR(tile)
      IendT=BOUNDS(ng)%IendT(tile)
      Jstr =BOUNDS(ng)%Jstr (tile)
      JstrR=BOUNDS(ng)%JstrR(tile)
      JstrT=BOUNDS(ng)%JstrT(tile)
      JstrV=BOUNDS(ng)%JstrV(tile)
      Jend =BOUNDS(ng)%Jend (tile)
      JendR=BOUNDS(ng)%JendR(tile)
      JendT=BOUNDS(ng)%JendT(tile)
!
!-----------------------------------------------------------------------
! If appropriate, initialize time-averaged diagnostic arrays.
!-----------------------------------------------------------------------
!
      IF (((iic(ng).gt.ntsDIA(ng)).and.                                 &
     &     (MOD(iic(ng)-1,nDIA(ng)).eq.0)).or.                          &
     &    ((nrrec(ng).gt.0).and.(iic(ng).eq.ntstart(ng)))) THEN
        DO ivar=1,NDbio2d
          DO j=Jstr,Jend
            DO i=Istr,Iend
              DiaBio2d(i,j,ivar)=0.0_r8
            END DO
          END DO
        END DO
        DO ivar=1,NDbio3d
          DO k=1,N(ng)
            DO j=Jstr,Jend
              DO i=Istr,Iend
                DiaBio3d(i,j,k,ivar)=0.0_r8
              END DO
            END DO
          END DO
        END DO
      END IF
!----------------------------------------------------------------------
!                       Randomization Routine
!----------------------------------------------------------------------
        CALL RANDOM_NUMBER(arr)
        call indexx(npmax,arr,indx)
        call rank(npmax,indx,irank)
      MyThid=0  ! this is passed to PLANKTON, but not used by it.
!
!-----------------------------------------------------------------------
!  Add biological Source/Sink terms.
!-----------------------------------------------------------------------
!
!  Set time-stepping size (days) according to the number of iterations.
!
      dtsecs=dt(ng)/REAL(BioIter(ng),r8)
!
!  Compute inverse thickness to avoid repeated divisions.
!
      exit_flag = NoError
      J_LOOP : DO j=Jstr,Jend
        DO k=1,N(ng)
          DO i=Istr,Iend
            Hz_inv(i,k)=1.0_r8/Hz(i,j,k)
          END DO
        END DO
!  Restrict biological tracer to be positive definite. If a negative
!  concentration is detected, nitrogen is drawn from the most abundant
!  pool to supplement the negative pools to a lower limit of MinVal
!  which is set to 1E-6 above.
!
!
!  Notice that at input all tracers are in transport units: m Tunits.
!      Change to normal tracer units here
!  !  Load biological tracers into local arrays.
!  Indelicately handle negative values by simply setting them positive.
!
        DO k=1,N(ng)
          DO i=Istr,Iend
            DO itrc=1,NBT
              ibio=idbio(itrc)
              Bio(i,k,ibio)=MAX(MinVal,t(i,j,k,nstp,ibio))
              Bio_bak(i,k,ibio)=Bio(i,k,ibio)
            END DO
          END DO
        END DO
!
!  Get potential temperature 
!
        DO k=1,N(ng)
          DO i=Istr,Iend
            Bio(i,k,itemp)=t(i,j,k,nstp,itemp)
          END DO
        END DO
!
!  Calculate surface Photosynthetically Available Radiation (PAR).  The
!  net shortwave radiation is scaled back to Watts/m2 and multiplied by
!  the fraction that is photosynthetically available, PARfrac.
!
        DO i=Istr,Iend
          PARsur(i)=PARfrac(ng)*srflx(i,j)*rho0*Cp
        END DO
!
        ITER_LOOP: DO Iter=1,BioIter(ng)
!
!  Compute light attenuation as function of depth.
!
          DO i=Istr,Iend
            PAR=PARsur(i)
            IF (PARsur(i).gt.0.0_r8) THEN              ! day time
              DO k=N(ng),1,-1
!
!  Attenuate the light to the center of the grid cell. Here, AttSW is
!  the light attenuation due to seawater and AttPhy is the attenuation
!  due to phytoplankton (self-shading coefficient).
!
                sumpy=0.0_r8
                do kk=1,npmax
                  sumpy = sumpy+Bio(i,k,iPhyt(kk))
                end do
                Att=EXP(-0.5_r8*(d_k0+d_kc*sumpy)*Hz(i,j,k))
                PAR=PAR*Att
                Light(i,k)=PAR
!
!  Attenuate the light to the bottom of the grid cell.
!
                PAR=PAR*Att
              END DO
            ELSE                                       ! night time
              DO k=1,N(ng)
                Light(i,k)=0.0_r8
              END DO
            END IF
          END DO
!
          DO k=1,N(ng)
            DO i=Istr,Iend
!             create interface to DARWIN
              do kk=1,npmax
                phyto(kk) = Bio(i,k,iPhyt(kk))
              end do
              do kk=1,nzmax
                zooP(kk)  = Bio(i,k,iZooP(kk))
              end do
              do kk=1,nzmax
                zooN(kk)  = Bio(i,k,iZooN(kk))
              end do
              do kk=1,nzmax
                zooSi(kk) = Bio(i,k,iZooSi(kk))
              end do
              PO4local    = Bio(i,k,iPO4)
              NO3local    = Bio(i,k,iNO3)
              Silocal     = Bio(i,k,iSi)
              NO2local    = Bio(i,k,iNO2)
              NH4local    = Bio(i,k,iNH4)
              DOPlocal    = Bio(i,k,iDOP)
              DONlocal    = Bio(i,k,iDON)
              POPlocal    = Bio(i,k,iPOP)
              PONlocal    = Bio(i,k,iPON)
              PSilocal    = Bio(i,k,iPSi)
              PARlocal    = Light(i,k)
              Tlocal      = Bio(i,k,itemp)
              Slocal      = Bio(i,k,isalt)
! --------------------------
!             Initialize diagnostics vectors to zero before 
!             entering plankton.F
              DO ivar=1,NDbio2d
                DiaBio2dLocal(ivar)=0.0_r8
              END DO
              DO ivar=1,NDbio3d
                DiaBio3dLocal(ivar)=0.0_r8
              END DO
              call DARWIN_PLANKTON(dtsecs,phyto, zooP, zooN, zooSi,     &
     &                       PO4local, NO3local, Silocal,               &
     &                       NO2local, NH4local,                        &
     &                       DOPlocal, DONlocal,                        &
     &                       POPlocal, PONlocal, PSilocal,              &
     &                       PARlocal,Tlocal, Slocal,                   &
     &                       dzlocal,                                   &
     &                       debug,                                     &
     &                       irank,                                     &
     &                       DiaBio2dLocal, diaBio3dLocal,              &
     &                       MyThid,i,j,k,ng)
              do kk=1,npmax
                Bio(i,k,iPhyt(kk)) = phyto(kk)
              end do
              do kk=1,nzmax
                Bio(i,k,iZooP(kk)) = zooP(kk) 
              end do
              do kk=1,nzmax
                Bio(i,k,iZooN(kk)) =  zooN(kk) 
              end do
              do kk=1,nzmax
                Bio(i,k,iZooSi(kk))= zooSi(kk) 
              end do
              Bio(i,k,iPO4)  = PO4local  
              Bio(i,k,iNO3)  = NO3local  
              Bio(i,k,iSi)   = Silocal   
              Bio(i,k,iNO2)  = NO2local  
              Bio(i,k,iNH4)  = NH4local  
              Bio(i,k,iDOP)  = DOPlocal  
              Bio(i,k,iDON)  = DONlocal  
              Bio(i,k,iPOP)  = POPlocal  
              Bio(i,k,iPON)  = PONlocal  
              Bio(i,k,iPSi)  = PSilocal  
!             Update big Diagnostics variables with that 
!             determined in plankton.F
              DO ivar=1,NDbio2d
                DiaBio2d(i,j,ivar)=DiaBio2d(i,j,ivar)+                  &
                                   DiaBio2dLocal(ivar)
              END DO
              DO ivar=1,NDbio3d
                DiaBio3d(i,j,k,ivar)=DiaBio3d(i,j,k,ivar)+              &
                                     DiaBio3dLocal(ivar)
              END DO
            END DO
          END DO
! ================ ADD SINKING HERE cae/ng 2 Oct 2007 ========================
          DO i=Istr,Iend
            DO kk=1,npmax
              flux_top(i,iPhyt(kk))=0.0d0
            END DO
            flux_top(i,iPOP)=0.0d0
            flux_top(i,iPON)=0.0d0
            flux_top(i,iPOFe)=0.0d0
            flux_top(i,iPSi)=0.0d0
          END DO
          DO k=N(ng),2,-1
           DO i=Istr,Iend
             !using Bio variables, calculate flux through bottom 
             !calculate dzlocal (perhaps as above in this code)
             flux_topPOPorig=flux_top(i,iPOP)
             dzlocal = Hz(i,j,k)!correct dz??
             cff=dtsecs/dzlocal
             !----------------Phytoplankton Sinking-----------------
             DO kk=1,npmax
              flux_bot(i,iPhyt(kk))=wsink(kk)*Bio(i,k,iPhyt(kk))
              delta(i,iPhyt(kk))=cff*(flux_top(i,iPhyt(kk))             &

       &                -flux_bot(i,iPhyt(kk)))
              IF (Bio(i,k,iPhyt(kk))+delta(i,iPhyt(kk)).lt.BiolocalMinP) THEN
                flux_bot(i,iPhyt(kk))=MAX(0.0_r8,flux_top(i,iPhyt(kk))- &

       &            (BiolocalMinP-Bio(i,k,iPhyt(kk)))/cff)
                delta(i,iPhyt(kk))=cff*(flux_top(i,iPhyt(kk))-          &

       &             flux_bot(i,iPhyt(kk)))
              END IF 
              Bio(i,k,iPhyt(kk))= Bio(i,k,iPhyt(kk))+delta(i,iPhyt(kk))
              flux_top(i,iPhyt(kk))=flux_bot(i,iPhyt(kk))
             END DO
             !----------------Particulates Sinking-----------------
             flux_bot(i,iPOP) =wp_sink*Bio(i,k,iPOP)
             flux_bot(i,iPON) =wn_sink*Bio(i,k,iPON)
             flux_bot(i,iPOFe)=wfe_sink*Bio(i,k,iPOFe)
             flux_bot(i,iPSi) =wsi_sink*Bio(i,k,iPSi)
             delta(i,iPOP) =cff*(flux_top(i,iPOP) -flux_bot(i,iPOP))
             delta(i,iPON) =cff*(flux_top(i,iPON) -flux_bot(i,iPON))
             delta(i,iPOFe)=cff*(flux_top(i,iPOFe)-flux_bot(i,iPOFe))
             delta(i,iPSi) =cff*(flux_top(i,iPSi) -flux_bot(i,iPSi))
             if ((Bio(i,k,iPOP)+delta(i,iPOP)).lt.(BiolocalMinP)) then
               flux_bot(i,iPOP)=MAX(0.0_r8,flux_top(i,iPOP)-            &
       &           (BiolocalMinP-Bio(i,k,iPOP))/cff)
                delta(i,iPOP)=cff*(flux_top(i,iPOP)-flux_bot(i,iPOP))
             end if 
             if ((Bio(i,k,iPON)+delta(i,iPON)).lt.(BiolocalMinN)) then
               flux_bot(i,iPON)=MAX(0.0_r8,flux_top(i,iPON)-            &
       &            (BiolocalMinN-Bio(i,k,iPON))/cff)
               delta(i,iPON)=cff*(flux_top(i,iPON)-flux_bot(i,iPON))
             end if 
             if ((Bio(i,k,iPSi)+delta(i,iPSi)).lt.(BiolocalMinSi)) then
               flux_bot(i,iPSi)=MAX(0.0_r8,flux_top(i,iPSi)-            &
       &                    (BiolocalMinSi-Bio(i,k,iPSi))/cff)
               delta(i,iPSi)=cff*(flux_top(i,iPSi)-flux_bot(i,iPSi))
             end if 
             if ((Bio(i,k,iPOFe)+delta(i,iPOFe)).lt.(BiolocalMinFe)) then
               flux_bot(i,iPOFe)=MAX(0.0_r8,flux_top(i,iPOFe)-          &
       &            (BiolocalMinFe-Bio(i,k,iPOFe))/cff)
               delta(i,iPOFe)=cff*(flux_top(i,iPOFe)-flux_bot(i,iPOFe))
             end if 
             Bio(i,k,iPOP)= Bio(i,k,iPOP)+delta(i,iPOP)
             Bio(i,k,iPON)= Bio(i,k,iPON)+delta(i,iPON)
             Bio(i,k,iPSi)= Bio(i,k,iPSi)+delta(i,iPSi)
             Bio(i,k,iPOFe)= Bio(i,k,iPOFe)+delta(i,iPOFe)
             flux_top(i,iPOP)=flux_bot(i,iPOP)
             flux_top(i,iPON)=flux_bot(i,iPON)
             flux_top(i,iPSi)=flux_bot(i,iPSi)
            do kk=1,npmax
              DiaBio3d(i,j,k,iPsink(kk)) =                              &
     &        DiaBio3d(i,j,k,iPsink(kk)) + delta(i,iPhyt(kk))
            end do
            DiaBio3d(i,j,k,isinkPOP)=DiaBio3d(i,j,k,isinkPOP)+          &
     &                               delta(i,iPOP)
            DiaBio3d(i,j,k,isinkPON)=DiaBio3d(i,j,k,isinkPON)+          &
     &                               delta(i,iPON)
            DiaBio3d(i,j,k,isinkPSi)=DiaBio3d(i,j,k,isinkPSi)+          &
     &                               delta(i,iPSi)
           END DO
         END DO
!
         !Now do case of k=1
         k=1
         DO i=Istr,Iend
           dzlocal = Hz(i,j,k)
           cff=dtsecs/dzlocal
           do kk=1,npmax
             delta(i,iPhyt(kk))=cff*(flux_top(i,iPhyt(kk)))
             Bio(i,k,iPhyt(kk))= Bio(i,k,iPhyt(kk))+delta(i,iPhyt(kk))
           end do
           !FOR PARTICULATES allow flux_bot to occur.  
           flux_bot(i,iPOP) =wp_sink*Bio(i,k,iPOP)
           flux_bot(i,iPON) =wn_sink*Bio(i,k,iPON)
           flux_bot(i,iPSi) =wsi_sink*Bio(i,k,iPSi)
           delta(i,iPOP) =cff*(flux_top(i,iPOP) -flux_bot(i,iPOP))
           delta(i,iPON) =cff*(flux_top(i,iPON) -flux_bot(i,iPON))
           delta(i,iPOFe)=cff*(flux_top(i,iPOFe)-flux_bot(i,iPOFe))
           delta(i,iPSi) =cff*(flux_top(i,iPSi) -flux_bot(i,iPSi))
           if ((Bio(i,k,iPOP)+delta(i,iPOP)).lt.(BiolocalMinP)) then
             flux_bot(i,iPOP)=MAX(0.0_r8,flux_top(i,iPOP)-              &
       &           (BiolocalMinP-Bio(i,k,iPOP))/cff)
              delta(i,iPOP)=cff*(flux_top(i,iPOP)-flux_bot(i,iPOP))
           end if 
           if ((Bio(i,k,iPON)+delta(i,iPON)).lt.(BiolocalMinN)) then
             flux_bot(i,iPON)=MAX(0.0_r8,flux_top(i,iPON)-              &
       &            (BiolocalMinN-Bio(i,k,iPON))/cff)
             delta(i,iPON)=cff*(flux_top(i,iPON)-flux_bot(i,iPON))
           end if 
           if ((Bio(i,k,iPSi)+delta(i,iPSi)).lt.(BiolocalMinSi)) then
             flux_bot(i,iPSi)=MAX(0.0_r8,flux_top(i,iPSi)-              &
       &                    (BiolocalMinSi-Bio(i,k,iPSi))/cff)
             delta(i,iPSi)=cff*(flux_top(i,iPSi)-flux_bot(i,iPSi))
             end if 
           Bio(i,k,iPOP)= Bio(i,k,iPOP)+delta(i,iPOP)
           Bio(i,k,iPON)= Bio(i,k,iPON)+delta(i,iPON)
           Bio(i,k,iPSi)= Bio(i,k,iPSi)+delta(i,iPSi)
            do kk=1,npmax
              DiaBio3d(i,j,k,iPsink(kk)) =                              &
     &        DiaBio3d(i,j,k,iPsink(kk)) + delta(i,iPhyt(kk))
            end do
            DiaBio3d(i,j,k,isinkPOP)=DiaBio3d(i,j,k,isinkPOP)+          &
     &                               delta(i,iPOP)
            DiaBio3d(i,j,k,isinkPON)=DiaBio3d(i,j,k,isinkPON)+          &
     &                               delta(i,iPON)
            DiaBio3d(i,j,k,isinkPSi)=DiaBio3d(i,j,k,isinkPSi)+          &
     &                               delta(i,iPSi)
!
!           finally, add flux_bot to 2d sediments
            SedPOP(i,j)  = SedPOP(i,j)  + dtsecs*flux_bot(i,iPOP)
            SedPON(i,j)  = SedPON(i,j)  + dtsecs*flux_bot(i,iPON)
            SedPOSi(i,j) = SedPOSi(i,j) + dtsecs*flux_bot(i,iPSi)
          END DO
!========================== END SINKING ===============================
        END DO ITER_LOOP
!
!-----------------------------------------------------------------------
!  Update global tracer variables (m Tunits).
!-----------------------------------------------------------------------
!
!-------------------------check Bio --------------------------------------
!  Here on Bio_bak
!----------------------------recalc t --------------------------------
        DO itrc=1,NBT
          ibio=idbio(itrc)
          DO k=1,N(ng)
            DO i=Istr,Iend
              dummyt00=t(i,j,k,nnew,ibio)*Hz_inv(i,k)
              t(i,j,k,nnew,ibio)=MIN(t(i,j,k,nnew,ibio),0.0_r8) +       &
      &                               (Bio(i,k,ibio)*Hz(i,j,k))
               dummyt0=t(i,j,k,nstp,ibio)
               dummyt1=t(i,j,k,nnew,ibio)*Hz_inv(i,k)
               IF ( (dummyt1.lt. -1.0d-6) .or. (dummyt1.gt.1000) ) THEN
                exit_flag=1 
                GO TO 100
              END IF
              t(i,j,k,3,ibio)=t(i,j,k,nnew,ibio)*Hz_inv(i,k)
            END DO
          END DO
        END DO
      END DO J_LOOP
100   CONTINUE
!
! If in mpi-mode, then get maximum of exit_flags
!
        buffer(1)=exit_flag
        Nreduce=1
        op_handle(1:npmax)='MAX'
        CALL mp_reduce (ng, iNLM, Nreduce, buffer, op_handle)
        exit_flag=buffer(1)
        IF (exit_flag.ne.NoError) RETURN
 10       FORMAT (1x,a,i3,a,e14.6,a,i3,a,e14.6,a)
 20       FORMAT (1x,a,i3,a,i4,a,1x,i6,a,1x,i6)
 30       FORMAT (1x,a,i2,a,e14.6,a,i2,a,e14.6)
 40       FORMAT (1x,a,i3,a,e14.6,a,i3,a,e14.6)
      buffer(1:npmax)=ksatPO4(1:npmax)
      op_handle(1:npmax)='MAX'
      CALL mp_reduce (ng, iNLM, npmax, buffer, op_handle)
      DO kk=1,npmax
        IF (ksatPO4(kk) .NE. buffer(kk)) THEN
          print *,'ksatPO4,max(ksatPO4)=',ksatNH4,phytomaxP(kk)
          STOP 'ABNORMAL END: parameter ksatPO4(kk) not same on all procs'
        END IF 
      END DO 
      RETURN
      END SUBROUTINE biology_tile
! ----------------------------------------------------------------------
         SUBROUTINE INDEXX(n,arr,indx)
! ----------------------------------------------------------------------
         INTEGER n,indx(n),M,NSTACK
         REAL arr(n)
         PARAMETER (M=7, NSTACK=50)
         INTEGER ii, indxt,ir,itemp,jj, jstack, kk, ll, istack(NSTACK)
         REAL a
! ----------------------------------------------------------------------
         DO jj=1,n
           indx(jj)=jj
         enddo
         jstack=0
         ll=1
         ir=n
    1    if(ir-ll.lt.M)then
           do jj=ll+1,ir
             indxt=indx(jj)
             a=arr(indxt)
             do ii=jj-1,ll,-1
               if(arr(indx(ii)).le.a)goto 2
               indx(ii+1)=indx(ii)
             enddo
             ii=ll-1
    2        indx(ii+1)=indxt
           enddo
           if(jstack.eq.0)return
           ir=istack(jstack)
           ll=istack(jstack-1)
           jstack=jstack-2
         else
           kk=(ll+ir)/2.0
           itemp=indx(kk)
           indx(kk)=indx(ll+1)
           indx(ll+1)=itemp
           if (arr(indx(ll)).gt.arr(indx(ir)))then
             itemp=indx(ll)
             indx(ll)=indx(ir)
             indx(ir)=itemp
           endif
           if(arr(indx(ll+1)).gt.arr(indx(ir)))then
             itemp=indx(ll+1)
             indx(ll+1)=indx(ir)
             indx(ir)=itemp
           endif
           if(arr(indx(ll)).gt.arr(indx(ll+1)))then
             itemp=indx(ll)
             indx(ll)=indx(ll+1)
             indx(ll+1)=itemp
           endif
           ii=ll+1
           jj=ir
           indxt=indx(ll+1)
           a=arr(indxt)
    3      continue
               ii=ii+1
           if(arr(indx(ii)).lt.a)goto 3
    4      continue
             jj=jj-1
           if(arr(indx(jj)).gt.a)goto 4
           if(jj.lt.ii)goto 5
           itemp=indx(ii)
           indx(ii)=indx(jj)
           indx(jj)=itemp
           goto 3
    5      indx(ll+1)=indx(jj)
           indx(jj)=indxt
           jstack=jstack+2
           if(jstack.gt.NSTACK)pause 'NSTACK too small in indexx'
           if(ir-ii+1.ge.jj-1)then
             istack(jstack)=ir
             istack(jstack-1)=ii
             ir=jj-1
           else
             istack(jstack)=jj-1
             istack(jstack-1)=ll
             ll=ii
           endif
         endif
         goto 1
         RETURN
         END SUBROUTINE INDEXX
! ----------------------------------------------------------------------
         SUBROUTINE RANK(n,indx,irank)
! ----------------------------------------------------------------------
         INTEGER n,indx(N),irank(N)
         INTEGER j
         do j=1,n
           irank(indx(j))=j
         enddo
         return
         END SUBROUTINE RANK
      END MODULE biology_mod
