      MODULE DARWIN_GENERATE_PHYTO_MOD
      implicit none
      PRIVATE
      PUBLIC  :: DARWIN_GENERATE_PHYTO
      CONTAINS
!C $Header: /u/gcmpack/MITgcm_contrib/darwin/pkg/darwin/darwin_generate_phyto.F,v 1.5 2007/12/12 21:19:01 jahn Exp $
!C $Name:  $
!c ==========================================================
!c SUBROUTINE DARWIN_GENERATE_PHYTO
!c generate parameters for "functional group" of phyto (index np)
!c using a "Monte Carlo" approach
!c         Mick Follows, Scott Grant Fall/Winter 2005
!c         Stephanie Dutkiewicz Spring/Summer 2005
!c ==========================================================
        SUBROUTINE DARWIN_GENERATE_PHYTO(myThid, np, seedtype, seedpar)
        USE mod_kinds
        USE mod_biology
        USE darwin_random_mod
        implicit none
!C !INPUT PARAMETERS: ===================================================
!C  myThid               :: thread number
        INTEGER myThid
!C     === Functions ===
!C     === Local variables ===
!C     msgBuf    - Informational/error meesage buffer
      CHARACTER*(MAX_LEN_MBUF) msgBuf
        real(r8) RandNo
        real(r8) growthdays
        real(r8) mortdays
        real(r8) pday
        real(r8) year
        real(r8) month
        real(r8) fiveday
        real(r8) rtime
        real(r8) standin
        INTEGER np
        INTEGER nz
        INTEGER signvar
        INTEGER seedpar, seedtype
!c
        standin=0.d0
!c length of day (seconds)
        pday = 86400.0d0
!c each time generate another functional group add one to ngroups
        ngroups = ngroups + 1
!c Start with type of phytoplankton
        CALL DARWIN_RANDOM_INIT(seedtype, MyThid)
!c RANDOM NUMBERS
!c phyto either "small" (physize(np)=0.0) or "big" (physize(np)=1.0)
!c at this point independent of whether diatom or not
        RandNo = darwin_random(myThid)
        if(RandNo .gt. 0.500d0)then
          physize(np) = 1.0d0
        else
          physize(np) = 0.0d0
        end if
!c
!c phyto either diatoms (diatom=1.0) and use silica or not (diatom=0.0)
!c if they are large
        if (physize(np).eq.1.0d0) then
          RandNo = darwin_random(myThid)
          if(RandNo .gt. 0.500d0)then
            diatom(np) = 1.0d0
          else
            diatom(np) = 0.0d0
          end if
        else
           diatom(np) = 0.0d0
        endif
!c phyto either diazotrophs (diazotroph=1.0) or not (diazotroph=0.0)
        RandNo = darwin_random(myThid)
        if(RandNo .gt. 0.6700d0)then
          diazotroph(np) = 1.0d0
        else
          diazotroph(np) = 0.0d0
        end if
        diazotroph(np) = 0.0d0
!c nutrient source 
         if(diazotroph(np) .ne. 1.0d0)then
           RandNo = darwin_random(myThid)
           if (physize(np).eq.1.0d0) then   
             nsource(np) = 3
           else
            if(RandNo .gt. 0.670d0)then
              nsource(np) = 1
            elseif(RandNo .lt. 0.33d0)then
              nsource(np) = 2
            else
              nsource(np) = 3
            endif 
           endif
         else
              nsource(np) = 0
         end if 
!c Done with determining phytoplankton type
!------------------------------------------
!c Now start with parameters
        CALL DARWIN_RANDOM_INIT(seedpar, MyThid)
!c growth rates
        RandNo = darwin_random(myThid)
        if(physize(np) .eq. 1.0d0)then
          growthdays = Biggrow +Randno*Biggrowrange
        else
          growthdays = Smallgrow +RandNo*Smallgrowrange
        end if
!c but diazotrophs always slower due to energetics
        if(diazotroph(np) .eq. 1.0d0) then
            growthdays = growthdays * diaz_growfac
        endif
!c  increase diatom growth rate as a test
        if(diatom(np) .eq. 1.0d0) then
            growthdays = 0.4d0 
        endif
!c now convert to a growth rate
        if (growthdays.gt.0.d0) then
         mu(np) = (1.0d0/(growthdays*pday))*2.0d0  
         !double growth rates if using diurnal light regime
        else
         mu(np) = 0.d0
        endif
!c mortality and export fraction rates
        RandNo = darwin_random(myThid)
!c big/small phyto mortality rates..
        if(physize(np) .eq. 1.0d0)then
          mortdays = Bigmort +Randno*Bigmortrange
          ExportFracP(np)=Bigexport
        else
          mortdays = Smallmort +RandNo*Smallmortrange
          ExportFracP(np)=Smallexport
        end if
!c now convert to a mortality rate
        if (mortdays.gt.0.d0) then
          mortphy(np) = 1.0d0/(mortdays*pday)
        else
          mortphy(np) = 0.d0
        endif
!c..........................................................
!c generate phyto Temperature Function parameters  
!c.......................................................
        phytoTempCoeff(np) = tempcoeff1
        phytoTempExp1(np) = tempcoeff3
        if(physize(np) .eq. 1.0d0)then
          phytoTempExp2(np) = tempcoeff2_big
        else
          phytoTempExp2(np) = tempcoeff2_small
        endif
        RandNo = darwin_random(myThid)
        phytoTempOptimum(np) = tempmax - RandNo*temprange
        phytoDecayPower(np) = tempdecay
!c ...............................................
!c stoichiometric ratios for each functional group of phyto 
!c relative to phosphorus  - the base currency nutrient
!c set Si:P
        if(diatom(np) .eq. 1.0d0)then
          R_SiP(np) =  val_R_SiP_diatom
        else
          R_SiP(np) = 0.0d0
        end if
!c set N:P and iron requirement according to diazotroph status
        if(diazotroph(np) .eq. 1.0d0)then
          R_NP(np) = val_R_NP_diaz
          R_FeP(np) =  val_RFeP_diaz
        else
          R_NP(np) = val_R_NP
          R_FeP(np) = val_RFeP
        end if
!c set sinking rates according to allometry
        if (physize(np).eq.0) then
           wsink(np) = SmallSink
        else
            if (diatom(np).eq.1.0d0) then
               wsink(np) = BigSink
            else 
               wsink(np) = BigSink                      
            endif
        endif
!c half-saturation coeffs 
        RandNo = darwin_random(myThid)
        if(physize(np) .eq. 1.0d0)then
           ksatPO4(np) = BigPsat + RandNo*BigPsatrange
        else
           if (nsource(np).eq.3.or.nsource(np).eq.0) then
             ksatPO4(np) = SmallPsat + RandNo*SmallPsatrange
           else
             ksatPO4(np) = ProcPsat + RandNo*ProcPsatrange
           endif
        endif
        ksatNO3(np) = ksatPO4(np)*R_NP(np)
        ksatNO2(np) = ksatNO3(np)*ksatNO2fac 
!c Made ksatNH4 smaller since it is the preferred source
        ksatNH4(np) = ksatNO3(np)*ksatNH4fac
        ksatFeT(np) = 0.0_r8 
        ksatSi(np)  = val_ksatsi
!c High Light Groups for Large size:
              if(physize(np) .eq. 1.0d0)then
                 RandNo = darwin_random_normal(myThid)
                 ksatPAR(np) = abs(Bigksatpar+Bigksatparstd*RandNo)
                 RandNo = darwin_random_normal(myThid)
                 kinhib(np) = abs(Bigkinhib+Bigkinhibstd*RandNo)
              else
!c QQ remove someday
                 RandNo = darwin_random(myThid)
!c Low Light Groups for Small size:
                 RandNo = darwin_random_normal(myThid)
                 ksatPAR(np) = abs(smallksatpar+smallksatparstd*RandNo)
                 RandNo = darwin_random_normal(myThid)
                 kinhib(np) = abs(smallkinhib+smallkinhibstd*RandNo)
              endif
!c assume zoo(1) = small, zoo(2) = big
         zoosize(1) = 0.0d0
         zoosize(2) = 1.0d0
         ! if grazemax is lower for macrozoo, then they dont survive. make them equal
         grazemax(1) = GrazeFast 
         grazemax(2) = GrazeSlow 
         ExportFracZ(1)=ZooexfacSmall
         ExportFracZ(2)=ZooexfacBig
         mortzoo(1) = ZoomortSmall
         mortzoo(2) = ZoomortBig
         ExportFracGraz(1)=ExGrazFracbig
         ExportFracGraz(2)=ExGrazFracsmall
         kgrazesat(1)=kgrazesatSmall
         kgrazesat(2)=kgrazesatBig
          do nz=1,nzmax
!c palatibity according to "allometry"
!c big grazers preferentially eat big phyto etc...
           if (zoosize(nz).eq.physize(np)) then
              palat(np,nz)=palathi
              asseff(np,nz)=GrazeEffmod
           else
              if (physize(np).eq.0.d0) then
                asseff(np,nz)=GrazeEfflow
                palat(np,nz)=palatlo
              else
                asseff(np,nz)=GrazeEffhi
                palat(np,nz)=palatmed
              endif
           endif
!c diatoms even less palatible
           if (diatom(np).eq.1.d0) then
               palat(np,nz)= palat(np,nz)*diatomgraz
           endif
          enddo
        RETURN
        END SUBROUTINE DARWIN_GENERATE_PHYTO
!c ===========================================================
      END MODULE DARWIN_GENERATE_PHYTO_MOD
