      MODULE DARWIN_INIT_FIXED_MOD
      implicit none
      PRIVATE
      PUBLIC  :: DARWIN_INIT_FIXED
      CONTAINS
!C $Header: /u/gcmpack/MITgcm_contrib/darwin/pkg/darwin/darwin_init_fixed.F,v 1.6 2008/02/26 17:13:31 jahn Exp $
!C $Name:  $
!C===============================================================================
!CStartofinterface
      SUBROUTINE DARWIN_INIT_FIXED
!C     =============== Global data ==========================================
!C     === Global variables ===
        USE mod_kinds
        USE mod_biology
!C============== Local variables ============================================
      real(r8) pday
      INTEGER i,j,k,bi,bj
      INTEGER tmp
      INTEGER prec
!C     /--------------------------------------------------------------!C     |  initialise common block biochemical parameters               |
!C     \--------------------------------------------------------------/
!c c define 1 day in seconds
         pday = 86400.0_r8
!c attenuation coefficients
      d_k0=        4.d-2                   !atten coefficient water(m^-1)
      d_kc=        4.d-2*16.d0*1.d0        !atten coefficient phy((uM m)-1)
!c for chl
      chlpmax=40.d0                      ! mg Chl/mmolP
      chlpmin=16.d0                      ! mg Chl/mmolP
      istar=90.d0                        ! w/m2
!c iron related
      alpfe=     0.04d0                  !solubility of Fe dust
      scav=      0.4d0/(360.d0*86400.d0) !iron chem scavenging rate (s-1)
      ligand_tot=1.d-3                   !total ligand (uM)
      ligand_stab=2.d5                   !ligand stability rate ratio
      freefemax = .4d-3                  ! max free fe
!c
!c oxidation rates (nitrification) for ammonium and nitrite
!c i.e. Knita ...    NH4 -> NO2
!c i.e. Knitb ...    NO2 -> NO3
       Knita = 1.0d0/(10.0d0*pday) !old/orig value 
       Knitb = 1.0d0/(30.0d0*pday) !old/orig value 
!c critical light level (muEin/m2/s) after which oxidation starts
       PAR0 = 10.d0
!c
!c set growth days ...small or big organism?
       Smallgrow = .7d0 
       Biggrow   = .5d0 
       Smallgrowrange = 0.d0
       Biggrowrange = 0.d0
       diaz_growfac = 2.d0
       Allgrow   = .4d0
       Allgrowrange = .3d0 
!c set mort days ...small or big organism?
       Smallmort = 10.d0
       Bigmort   = 10.d0
       Smallmortrange = 0.d0
       Bigmortrange = 0.d0
!c set export fraction ...small or big organism?
       Smallexport = 0.2d0
       Bigexport   = 0.5d0
!c set sinking rates (m/s)... small or big organism?
       SmallSink = 0.0d0/pday
       BigSink = 0.5d0/pday   !0.5d0/pday
!c set parameters for light function for phyto growth (Watts/m2)
       smallksatpar =    0.012d0 ! 0.8d0
       smallksatparstd = 0.020d0  ! 0.3d0
       smallkinhib =     0.006d0   ! 2.0d0
       smallkinhibstd =  0.0001d0  ! 0.5d0
       Bigksatpar =      0.012d0  ! 0.35d0
       Bigksatparstd =   0.006d0  ! 0.1d0
       Bigkinhib =       0.001d0   ! 0.5d0
       Bigkinhibstd =    0.00005d0   ! 0.1d0
!c set temperature function
       tempcoeff1 = 1.d0/3.d0
       tempcoeff2_small = 0.001d0
       tempcoeff2_big   = 0.0003d0
       tempcoeff3 = 1.04d0
       tempmax = 25.d0      ! for california current nlg
       temprange = 20.d0    ! for california current nlg
       tempnorm = 0.3d0  ! 1.d0
       tempdecay = 4.d0
!c set phosphate half stauration constants .. small or big organism
       SmallPsat=0.015d0 !orig val
       BigPsat=0.035d0
       ProcPsat=0.01d0
       SmallPsatrange=0.02d0
       BigPsatrange=0.02d0
       ProcPsatrange=0.005d0
!c set NH4/NO2 frac, so that NH4/NO2 can be preferred nitrogen source
       ksatNH4fac=.50d0 ! original value
       ksatNO2fac=1.0d0  ! original value
!c set prochl lower half-sat
       prochlPsat=.85d0
!c ammonia and nitrite inhibition
       sig1 = 4.6d0
       sig2 = 4.6d0
       sig3 = 4.6d0
       ngrowfac = 1.d0
       ilight = 2.d0
!c set si half sat
       val_ksatsi=1.d0
!c set nutrient ratios for phyto
       val_R_SiP_diatom=16.0d0
       val_R_NP_diaz=40.0d0
       val_RFeP_diaz=7.5d-3
       val_R_NP=16.0d0
       val_RFeP=1.0d-3
!c grazing hlaf saturation
       kgrazesatSmall = 0.04d0 
       kgrazesatBig = 0.07d0 
       phygrazmin = 1d-10
       zoograzmin = 1d-9
!c set grazing rates .. small or big organism?
       GrazeFast = 1/(1.0d0*pday) 
       GrazeSlow = 1/(2.0d0*pday)
!c set grazing effeciency
       GrazeEfflow= 0.2d0 
       GrazeEffmod= 0.5d0 
       GrazeEffhi = 0.7d0
       GrazeEffZoo = 0.3d0
!c set palatibility
       palathi = 1.0d0
       palatmed = 0.4d0
       palatlo = 0.2d0
       palatzoo = 1.0d0
!c set palatibilty diatom factor
      diatomgraz = 0.7d0 
       olargegraz = 1.0d0
!c set faction graz to POM
       ExGrazfracbig = 0.8d0
       ExGrazfracsmall = 0.8d0
!c set zoo mortality
       ZoomortSmall = 1.0d0/(30.0d0*pday) !original value
       ZoomortBig = 1.0d0/(30.0d0*pday)   !original value 
!c set zoo exportfrac
       ZooexfacSmall = 0.2d0
       ZooexfacBig = 0.7d0
!c minimum phyto (below which grazing and mortality doesn't happen)
      phymin = 1.0d-10
!c DOM remin rates
         Kdop = 1.0d0/(50.0d0*pday) ! old/orig value
         Kdon = 1.0d0/(50.0d0*pday) ! old/orig value
         KdoFe = 1.0d0/(50.0d0*pday) ! old/orig value
!c Particulate detritus remin rates
!c z* = wx_sink/Kremin_X
!c for e-folding length scale, z* = 300 m
!c choose Kremin_X = 1/30 day-1, wx_sink = 10 m day-1
         Kpremin_P = 1.0d0/(30.0d0*pday) !old/orig value
         Kpremin_N = Kpremin_P
         Kpremin_Fe = Kpremin_P
         Kpremin_Si = 1.0d0/(300.0d0*pday) 
!c sinking rate for particulate matter (m/s)
         wp_sink = 10.0d0/pday  ! original value (13 Aug 2008)
         wn_sink = wp_sink
         wfe_sink = wp_sink
         wsi_sink = wp_sink
!c  -- minimum concentration of biological tracers
        !BiolocalMin = 1.0d-10
        BiolocalMinN = 1.6d-9!1.0e-10*16
        BiolocalMinP = 1.0d-10
        BiolocalMinFe = 1.0d-13!1.0e-10*1.0d-3
        BiolocalMinSi = 1.6d-9!1.0e-10*16
        RETURN
        END SUBROUTINE DARWIN_INIT_FIXED
!C============================================================================
      END MODULE DARWIN_INIT_FIXED_MOD
