      MODULE DARWIN_INIT_VARI_MOD
      implicit none
      PRIVATE
      PUBLIC  :: DARWIN_INIT_VARI
      CONTAINS
!C $Header: /u/gcmpack/MITgcm_contrib/darwin/pkg/darwin/darwin_init_vari.F,v 1.8 2008/02/25 21:09:57 jahn Exp $
!C $Name:  $
!c ==========================================================
!c SUBROUTINE DARWIN_INIT_VARI()
!c initialize stuff for generalized plankton model
!c adapted from NPZD2Fe - Mick Follows, Fall 2005
!c               modified - Stephanie Dutkiewicz, Spring 2006
!c ==========================================================
!c
        SUBROUTINE DARWIN_INIT_VARI(ng)
        USE mod_kinds
        USE mod_biology
        USE darwin_generate_phyto_mod, only : darwin_generate_phyto
        USE darwin_random_mod
        USE mod_iounits
        USE mod_parallel
        IMPLICIT NONE
!C !INPUT PARAMETERS: ===================================================
!C  myThid               :: thread number
      INTEGER ng
!C     === Functions ===
!C     === Local variables ===
!C     msgBuf    - Informational/error meesage buffer
        INTEGER IniUnit1, IniUnit2
        INTEGER bi, bj, k
        INTEGER np
        INTEGER nz
        INTEGER MyThid
        PARAMETER (MyThid = 1)  !cae need to think carefully about roms threads later
        INTEGER biggest_np, iphytovec, i,ii
        REAL(r8) rnd
!c seed randomization
        CALL DARWIN_RANDOM_INIT(BioSeed(ng), MyThid)
!c initialize total number of functional groups tried
         NPhytoSeeds=PhytoIndexMax
!        set up upper phyto, whose seeds need to be generated here
!        The reason to do this first is to have the seeds follow from BioSeed
!        And not from the last PhytoSeed entered in the input file.
         do np = NPhytoSeeds+1, npmax
           PhytoIndexMax = PhytoIndexMax+1
           PhytoIndex(np) = PhytoIndexMax
           rnd=darwin_random(MyThid)
           PhytoSeedType(np) = INT(rnd*1.0e6_r8)
           rnd=darwin_random(MyThid)
           PhytoSeedPar(np) = INT(rnd*1.0e6_r8)
           IF (Master) WRITE (stdout,10) '   Phyto ', np,               &
     &                            ' Index =',PhytoIndex(np),            &
     &                            ' SeedPT =',PhytoSeedType(np),        &
     &                            ' SeedPP =',PhytoSeedPar(np)
           call darwin_generate_phyto(MyThid, np,                       &
     &                  PhytoSeedType(np), PhytoSeedPar(np))
         end do
!        set up those (lower phyto) whose seeds were entered in darwin.in file
         do np = 1,NPhytoSeeds
           IF (Master) WRITE (stdout,10) '   Phyto ', np,               &
     &                            ' Index =',PhytoIndex(np),            &
     &                            ' SeedPT =',PhytoSeedType(np),        &
     &                            ' SeedPP =',PhytoSeedPar(np)
           call darwin_generate_phyto(MyThid, np,                       &
     &                  PhytoSeedType(np), PhytoSeedPar(np))
         end do
! do a quick check to make sure we don't have redundant PhytoSeeds
         do i = 1, npmax
           do np = 1, npmax
             if ( (i.NE.np) .AND.                                       &
     &            (PhytoSeedType(i).EQ. PhytoSeedType(np))  .AND.       &
                  (PhytoSeedPar(i) .EQ. PhytoSeedPar(np)) ) THEN
               WRITE(stdout,20) 'i=',i,'PSeedType=', PhytoSeedType(i),  &
                         'PSeedPar=', PhytoSeedPar(i) 
               WRITE(stdout,20) 'j=',np,'PSeedType=', PhytoSeedType(np),&
                         'PSeedPar=', PhytoSeedPar(np) 
               WRITE(stdout,30) 'Try different BioSeed'
               STOP 'DARWIN_INIT_VARI: PhytoSeeds are not unique.'
             end if 
           end do 
         end do 
 10  FORMAT (1x,a,i3,a,i3,a,i7,a,i7)
 20  FORMAT(1x,a,i3,2x,a,1x,i7,2x,a,1x,i7)
 30  FORMAT(1x,a)
!c %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
         open(15,file='plankton-ini-char.dat',status='unknown')
         open(16,file='plankton_ini_char_nohead.dat',status='unknown')
         write(15,*)'diat diaz size mu mort Rnp Rfep Rsip wsink         &
     & KsP KsN   KsFe   KsSi    palat1 palat2  Kpar  Kinh  Topt  nsrc   &
     & np'
         do np = 1, npmax
           write(15,111)diatom(np),diazotroph(np),physize(np),          &
     &                   1.0/(mu(np)*86400.), 1.0/(mortphy(np)*86400.), &
     &                   R_NP(np),R_FeP(np)*1000.,R_SiP(np),            &
     &                   wsink(np)*86400,                               &
     &                   KsatPO4(np),KsatNO3(np),KsatFeT(np)*1000.      &
     &                  ,KsatSi(np),                                    &
     &                   palat(np,1),palat(np,2),                       &
     &                   KsatPAR(np),Kinhib(np),                        &
     &                   phytoTempOptimum(np),nsource(np),np
            write(16,111)diatom(np),diazotroph(np),physize(np),         &
     &                   1.0/(mu(np)*86400.),1.0/(mortphy(np)*86400.),  &
     &                   R_NP(np),R_FeP(np)*1000.,R_SiP(np),            &
     &                   wsink(np)*86400,                               &
     &                   KsatPO4(np),KsatNO3(np),KsatFeT(np)*1000.      &
     &                  ,KsatSi(np),                                    &
     &                   palat(np,1),palat(np,2),                       &
     &                   KsatPAR(np),Kinhib(np),                        &
     &                   phytoTempOptimum(np),nsource(np),np
         end do
         close(15)
         close(16)
 110     format(3f4.0,f6.2,4f4.0,f5.1,4f7.3,2e11.2,2f9.4,f6.1,2i5)
 111     format(3f4.0,f6.2,4f4.0,f5.1,4f7.3,2f6.1,2f9.4,f6.1,2i5)
         RETURN 
         END SUBROUTINE DARWIN_INIT_VARI
!c ==========================================================
      END MODULE DARWIN_INIT_VARI_MOD
