      MODULE DARWIN_PLANKTON_MOD
      implicit none
      PRIVATE
      PUBLIC  :: DARWIN_PLANKTON
      CONTAINS
!c ====================================================================
!c SUBROUTINE PLANKTON
!c 1. Local ecological interactions for models with many phytoplankton
!c    "functional groups"
!c 2. Timestep plankton and nutrients locally
!c 3. Includes explicit DOM and POM
!c 4. Remineralization of detritus also determined in routine
!c 5. Sinking particles and phytoplankton
!c 6. NOT in this routine: iron chemistry
!c
!c       Mick Follows, Scott Grant, Fall/Winter 2005
!c       Stephanie Dutkiewicz Spring/Summer 2006
!c ====================================================================
!c ====================================================================
!c 7. Modified to avoid negative concentrations.
!c
!c       Nicole Goebel, Chris Edwards, Sophie Rabouille, summer/fall 2007
!c       CAE: Updated to new grazing formulation in darwin_plankton v1.2 sp 2008
!c ====================================================================
         SUBROUTINE DARWIN_PLANKTON(dts,phyto, zooP, zooN, zooSi,       &
     &                       PO4local, NO3local, Silocal,               &
     &                       NO2local, NH4local,                        &
     &                       DOPlocal, DONlocal,                        &
     &                       POPlocal, PONlocal, PSilocal,              &
     &                       PARlocal,Tlocal, Slocal,                   &
     &                       dzlocal,                                   &
     &                       debug,                                     &
     &                       irank,                                     &
     &                       DiaBio2dLocal, diaBio3dLocal,              &
     &                       MyThid,i,j,k,ng)
         use mod_kinds
         use mod_biology
         use mod_scalars
         USE mod_diags
         USE mod_ncparam
         !use hpsort_mod
         implicit none
!C !INPUT PARAMETERS: ===================================================
!C  myThid               :: thread number
      INTEGER myThid, ng
      INTEGER i, j, k
!c === GLOBAL VARIABLES =====================
!c npmax = no of phyto functional groups
!c nzmax = no of grazer species
!c phyto = phytoplankton
!c zoo   = zooplankton
         real(r8) dts
         real(r8) phyto(npmax)
         real(r8) zooP(nzmax)
         real(r8) zooN(nzmax)
         real(r8) zooFe(nzmax)
         real(r8) zooSi(nzmax)
         real(r8) PP
         real(r8) Nfix
         real(r8) PPxdts
         real(r8) PO4local
         real(r8) NO3local
         real(r8) FeTlocal
         real(r8) Silocal
         real(r8) NO2local
         real(r8) NH4local
         real(r8) Nlocal
         real(r8) DOPlocal
         real(r8) DONlocal
         real(r8) DOFelocal
         real(r8) POPlocal 
         real(r8) PONlocal
         real(r8) POFelocal
         real(r8) PSilocal
         real(r8) phytoup(npmax)
         real(r8) PARlocal
         real(r8) Tlocal
         real(r8) Slocal
         real(r8) freefelocal
         real(r8) inputFelocal
         real(r8) dzlocal
         INTEGER debug
         real(r8) :: DiaBio2dLocal(NDbio2d)
         real(r8) :: DiaBio3dLocal(NDbio3d)
!c LOCAL VARIABLES
!c -------------------------------------------------------------
         real(r8) allphyto, tmpz, grazphy, deltaPgrow, deltaPloss
         real(r8) val
!c WORKING VARIABLES
!c np = phytoplankton index
         integer np,ip,np2
!c nz = zooplankton index
         integer nz
!c variables for phytoplankton growth rate/nutrient limitation
!c phytoplankton specific nutrient limitation term
         real(r8) limit(npmax)
!c phytoplankton light limitation term
         real(r8) ilimit(npmax)
         real(r8) ngrow(npmax)
         real(r8) grow(npmax)
         real(r8) PspecificPO4(npmax)
         real(r8) phytoTempFunction(npmax)
         real(r8) dummy
         real(r8) Ndummy
         real(r8) Nsourcelimit(npmax)
         real(r8) Nlimit(npmax)
         real(r8) NO3limit(npmax)
         real(r8) NO2limit(npmax)
         real(r8) NH4limit(npmax)
! for check N limit scheme
         real(r8) Ndiff
         real(r8) NO3limcheck
         real(r8) NO2limcheck
         real(r8) Ndummy1
         LOGICAL check_nlim
!c [jbmodif] some new N terms
         integer N2only
         integer noNOdadv
         integer NOreducost
         real(r8) NO2zoNH4
         real(r8) NOXzoNH4
!c varible for mimumum phyto
         real(r8) phytomin(npmax)
!c  variables for zooplankton grazing rates
         real(r8) zooTempFunction(nzmax)
         real(r8) grazing_phyto
         real(r8) den, num
         real(r8) grazzoo, totphytzoo1
!c variables for nutrient uptake
         real(r8) consumpPO4
         real(r8) consumpNO3
         real(r8) consumpNO2
         real(r8) consumpNH4
         real(r8) consumpN
         real(r8) consumpSi
!c variables for reminerlaization of DOM and POM
         real(r8) DOPremin
         real(r8) DONremin
         real(r8) preminP
         real(r8) preminN
         real(r8) preminSi
!c for sinking matter
         real(r8) delpsinkP
         real(r8) delpsinkN
         real(r8) delpsinkSi
         real(r8) delpsinkphy(npmax)
!c variables for conversions from phyto and zoo to DOM and POM
         real(r8) totphy_dop
         real(r8) totphy_pop
         real(r8) totphy_don
         real(r8) totphy_pon
         real(r8) totphy_dosi
         real(r8) totphy_posi
         real(r8) totzoo_dop
         real(r8) totzoo_pop
         real(r8) totzoo_don
         real(r8) totzoo_pon
         real(r8) totzoo_posi
         real(r8) NO2prod
         real(r8) NO3prod
         real(r8) facpz
         real(r8) kpar, kinh
         real(r8) tmpr
         real(r8) prePOP,postPOP,preDOP,postDOP,prePO4
         real(r8) endPO4,prePON,postPON
         integer ITEST
!c reduction factor in case total consumption is higher than the
!c available local stock: control of nutrient pools and Phyto pools
         real(r8) facP,facN,facNH4,facNO2,facNO3,facSi,control_nut, fac
         real(r8) control_graz,control_grazeZooP,control_grazeZooN
         real(r8)  control_grazeZooSi,control_grazezoo
         real(r8) deltaZloss, deltaZgrow
         real(r8) DOPmin
         real(r8) control_remin,control_reminDOP,control_reminDON
         real(r8) control_premin
         real(r8) control_preminPOP,control_preminPON
         real(r8) control_preminP,control_preminN,control_preminSi
         real(r8) DONmin
         real(r8) zooPmin 
         real(r8) control_mortzooP,control_mortzooN
         real(r8) control_mortzooSi,control_mortzoo 
         real(r8) zooNmin 
         real(r8) zooSimin 
         real(r8) popmin
         real(r8) ponmin
         real(r8) posimin
         real(r8) NO3prodmin
         real(r8) control_NO3prod
         real(r8) NO2prodmin
         real(r8) control_NO2prod
         real(r8) NH4prodmin
         real(r8) control_mortphyto
         real(r8) PSimin
         real(r8) NO2min
         real(r8) NH4min
         real(r8) PhytoAll,zooPall,grz_phytoxdts,prePhyto,mortZooPxdts
         real(r8) Pfac, deltaP, endPhyto,endPhytoN,endZooN
         real(r8) preZooN,preZooP,prePhytoN,endZooP
         real(r8) preZooSi,endZooSi
         real(r8) deltaZooP, deltaZooN
         real(r8) deltaZooSi
         real(r8) deltaDOPremin, deltaDONremin
         real(r8) deltapreminP,deltapreminN,deltapreminSi
         real(r8) delNO2prod,delNO3prod,NO2diff,NO3diff
         real(r8) control_nprod,control_n02prod,control_n03prod
         real(r8) preNO2,preNO3,preNH4
         real(r8) endNO2,endNO3,endNH4
         real(r8) mindiff,tinyno
! For randomization of phytoplankton indices         
         REAL arr(npmax)
         INTEGER irank(npmax), indx(npmax)
         REAL(r8) phyt78grow, phyt78grow2,phyt78mort
         REAL(r8) phyt78graz,phyt78zoomort
         logical useNO3,useNO2,useNH4
         REAL(r8) dZ2dtcae
!c.................................................................
         tinyno=1e-15_r8
!c [jbmodif] init new N terms
!c  if those not using NO3 has
!c  N limit with denominator with NO3 or not: 0=NO3 in denom; 1=NO2 only
         N2only = 1
         noNOdadv = 1
!c energetic disadvantage of using NO2/No3: off=0, on=1
         NOreducost =0
!c set conversion factor to default value
         facP   =1.d0
         facNH4 =1.d0
         facNO2 =1.d0
         facNO3 =1.d0
         facN   =1.d0
         facSi  =1.d0
         control_nut =1.d0
         control_graz =1.d0
         control_preminP =1.d0
         control_preminN =1.d0
         control_preminSi =1.d0
         control_remin =1.d0
         control_nprod =1.d0
         control_mortphyto =1.d0
         control_mortzoo =1.d0
!c set sum totals to zero
         totphy_pop = 0.d0
         totphy_dop = 0.d0
         totphy_don = 0.d0
         totphy_pon = 0.d0
         totphy_posi = 0.d0
         totzoo_dop = 0.d0
         totzoo_pop = 0.d0
         totzoo_don = 0.d0
         totzoo_pon = 0.d0
         totzoo_posi = 0.d0
         consumpPO4 = 0.0d0
         consumpNO3 = 0.0d0
         consumpNO2 = 0.0d0
         consumpNH4 = 0.0d0
         consumpN   = 0.0d0
         consumpSi  = 0.0d0
! ******************* Generate Random Phyto Numbers ***********************
! ******************* END Generate Random Phyto Numbers ***********************
!c zeros for diagnostics
        PPxdts=0.d0
        PP=0.d0
        Nfix=0.d0
        PhytoAll=0.d0
        zooPall=0.d0
        grz_phytoxdts=0.d0
!c set up phytoplankton array to be used for grazing and mortality
         do ip=1,npmax
           np=irank(ip)
           dummy = phyto(np)-phymin
           phytomin(np)=max(dummy,0.d0)
         enddo
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!c Determine ZooPlankton Temp Dep. Function: will affect maximum
!c grazing rates
          do nz=1,nzmax  
!c              zooTempFunction(nz) = zooTempCoeff(nz)*EXP(
!c    &             zooTempExp(nz)*(Tlocal - zooTempOptimum(nz)))
            zooTempFunction(nz) = 1.0d0
          end do   
!c ******************** GROWTH OF PHYTO ****************************
!c Determine phytoplankton light limitation: will affect growth rate
          do ip = 1, npmax
            np=irank(ip)
            kpar=ksatPAR(np)! %now corrected within darwini_init_fixed-ng
            kinh=kinhib(np) !%now corrected within darwini_init_fixed-ng
            ilimit(np)=(1.0d0 - EXP(-PARlocal*kpar))                    &
     &                  *(EXP(-PARlocal*kinh)) /                        &
     &        ( kpar/(kpar+kinh)*EXP(kinh/kpar*LOG(kinh/(kpar+kinh))) )
            ilimit(np)=min(ilimit(np),1.d0)
!c cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!c Determine temperature Dependent Growth function for Phyto
               phytoTempFunction(np) = (                                &
     &                         (phytoTempExp1(np)**Tlocal)*             &
     &                         exp(- phytoTempExp2(np)*                 &
     &                         (abs(Tlocal - phytoTempOptimum(np)))**   &
     &                                      phytoDecayPower(np)))-      &
     &                         tempnorm
               phytoTempFunction(np) = phytoTempCoeff(np)*              &
     &                     max(phytoTempFunction(np), 1.d-10)
               phytoTempFunction(np) = min(phytoTempFunction(np),1.d0)
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!c Determine phytoplankton nutrient limitation as mimimum of 
!c P,N,Si,Fe. However N can be utilized in several forms, so
!c also determine which is used
            limit(np) = 1.0d0
!c P limitation
            dummy = PO4local/(PO4local+ksatPO4(np))
! 19 August 2010 multiplying by dts here (and in other lim factors below) 
! because when written, diagnostic files are divided by total time
            DiaBio3dLocal(ilimP(np))=dummy*dts
            if (dummy .lt. limit(np))  limit(np) = dummy         
!c Si limiation
            if (R_SiP(np) .ne. 0.0)then
               dummy = Silocal/(Silocal+ksatSi(np))
               DiaBio3dLocal(ilimSi(np))=dummy*dts
               if (dummy .lt. limit(np)) limit(np) = dummy      
            endif
!c N limitation
!c nsource: genetic preference for {1:NH4&NO2 2:NH4 3:ALL Sources}
!c Nsourcelimit marker for which nsource will be consumed {1:NO3 2:NO2 3:NH4}
          if(diazotroph(np) .ne. 1.0)then
               if (ksatNH4(np).gt.0.d0) then
                   NH4limit(np) = NH4local/(NH4local+ksatNH4(np))
               endif
! [jbmodif]
! NO2, if nsource is 1 or 3
               if (ksatNO2(np).gt.0.d0 .and. nsource(np).ne.2) then
                 if (N2only.eq.1 .and. nsource(np).eq.1) then
                  NO2limit(np) = NO2local/(NO2local+ksatNO2(np))        &
     &                    *EXP(-sig1*NH4local)
                  NO2limcheck = NO2local/(NO2local+ksatNO2(np))
                 else
                  if (ksatNO3(np).gt.0.d0) then
                   NO2limit(np)=NO2local/(NO3local+NO2local+ksatNO3(np))&
     &                    *EXP(-sig1*NH4local)
                   NO2limcheck=NO2local/(NO3local+NO2local+ksatNO3(np))
                  endif
                 endif
               endif
! NO3, if nsource is 3
               if (ksatNO3(np).gt.0.d0 .and. nsource(np).eq.3) then
                  NO3limit(np)=NO3local/(NO3local+NO2local+ksatNO3(np)) &
     &                    *EXP(-sig1*NH4local)
                  NO3limcheck=NO3local/(NO3local+NO2local+ksatNO3(np))
               endif
               if (nsource(np).eq.2) then
                  NO2limit(np) = 0.d0
                  NO3limit(np) = 0.d0
                  NO2limcheck  = 0.d0
                  NO3limcheck  = 0.d0
               endif
               if (nsource(np).eq.1) then
                 NO3limit(np) = 0.d0
                 NO3limcheck  = 0.d0
               endif
               if (nsource(np).eq.3) then
! don't do anything
               endif
               Ndummy = NO3limit(np)+NO2limit(np)+NH4limit(np)
               check_nlim=.FALSE.
               if (check_nlim) then
                  Ndummy1=NO3limcheck+NO2limcheck
                  if (Ndummy.gt.0.d0.and.Ndummy.lt.Ndummy1) then
                   print*,'QQ N limit WARNING',Ndummy, Ndummy1,         &
     &                             NO3local,NO2local,NH4local
                    Ndiff=Ndummy1-NH4limit(np)
                    NO2limit(np)=Ndiff *                                &
     &                     NO2limit(np)/(NO2limit(np)+NO3limit(np))
                    NO3limit(np)=Ndiff *                                &
     &                     NO3limit(np)/(NO2limit(np)+NO3limit(np))
                    Ndummy = NO3limit(np)+NO2limit(np)+NH4limit(np)
                  endif
               endif
               if (Ndummy.gt.1.d0) then
                 NO3limit(np) = NO3limit(np)/Ndummy
                 NO2limit(np) = NO2limit(np)/Ndummy
                 NH4limit(np) = NH4limit(np)/Ndummy 
               endif
               Nlimit(np)=NO3limit(np)+NO2limit(np)+NH4limit(np)
!  CHECK ON NLIMIT<0
               if (Nlimit(np).le.0.d0) then
                 Nlimit(np)=0.d0   !1d-10
               endif
! disadvantage of oxidized inorganic N
              ngrow(np) = 1.0d0
!c lower growth for higher NO3 consumption at higher light
! one possible way of counting cost of reducing NOX
               if (NOreducost .eq. 1)then 
                if (Nlimit(np).le.0.d0) then
                  ngrow(np)=1.d0
                else
                 ngrow(np)= (10.d0*4.d0 +2.d0)   /                      &
     &              (10.d0*4.d0 +2.d0*NH4limit(np)/Nlimit(np)           &
     &                           +8.d0*NO2limit(np)/Nlimit(np)          &
     &                           +10.d0*NO3limit(np)/Nlimit(np))
                 ngrow(np)=min(ngrow(np),1.d0)
                endif
               endif
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!c Now Check Against General Nutrient Limiting Tendency
            if (ksatNH4(np).gt.0.d0.or.ksatNO2(np).gt.0.d0              &
     &              .or.ksatNO3(np).gt.0.d0) then
                if(Nlimit(np) .lt. limit(np)) limit(np) = Nlimit(np)
            endif
          else
            ngrow(np)=1.d0
            Nlimit(np)=1.d0
            NO3limit(np)=0.d0
            NO2limit(np)=0.d0
            NH4limit(np)=0.d0
          endif   ! diaz
            DiaBio3dLocal(ilimN(np))=Nlimit(np)*dts
!            if ((np.eq.5).and.(k.eq.28).and.(i.eq.20).and.(j.eq.20)) then
!              print*,'ilimN=',Nlimit(np)*dts
!            endif
          limit(np)=min(limit(np),1.d0)
!c ********************* NUTRIENT UPTAKE *******************************
!c determine nutrient uptake
!c consumption - sum of phytoplankton contributions
!c phospate uptake by each phytoplankton
            DiaBio3dLocal(ilimI(np))=ilimit(np)*dts
            DiaBio3dLocal(ilimT(np))=phytoTempFunction(np)*dts
               grow(np)=ngrow(np)*mu(np)*limit(np)*ilimit(np)*          &
      &                            phytoTempFunction(np)
               PspecificPO4(np) = grow(np)*phyto(np)
               consumpPO4 = PspecificPO4(np)
               consumpSi  = PspecificPO4(np)*R_SiP(np)
!c Nitrogen Consumption .......................
               consumpNO3 = 0.d0
               consumpNO2 = 0.d0
               consumpNH4 = 0.d0
               if(diazotroph(np) .ne. 1.0)then
                if (Nlimit(np).gt.0.d0) then
                 consumpNO3 =                                           &
      &              (NO3limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
                 consumpNO2 =                                           &
      &              (NO2limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
                 consumpNH4 =                                           &
      &              (NH4limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
                endif
               endif
               consumpN=(consumpNO3+consumpNO2+consumpNH4)
!c nsource: genetic preference for {1:NH4&NO2 2:NH4 3:ALL Sources}
            if (nsource(np).eq.1) then
              useNH4=.true.
              useNO2=.true.
              useNO3=.false.
            elseif (nsource(np).eq.2) then
              useNH4=.true.
              useNO2=.false.
              useNO3=.false.
            else !if (nsource(np).eq.3) then
              useNH4=.true.
              useNO2=.true.
              useNO3=.true.
            endif
! Control of the total consumption
            dummy=consumpPO4*dts
            if(dummy.gt.(PO4local-BiolocalMinP))                        &
     &         facP=max(tinyno,(PO4local-BiolocalMinP)/dummy)
            dummy=consumpNH4*dts
            Nlocal=0.0_r8
            if (useNH4) then
              if(dummy.gt.(NH4local-BiolocalMinN))                      &
     &          facNH4=max(tinyno,(NH4local -BiolocalMinN)/dummy)
              Nlocal=Nlocal+NH4local
            else
              facNH4=1.0_r8
            endif
            dummy=consumpNO2*dts
            if (useNO2) then
              if(dummy.gt.NO2local-BiolocalMinN)                        &
     &          facNO2=max(tinyno,(NO2local -BiolocalMinN)/dummy)
              Nlocal=Nlocal+NO2local
            else
              facNO2=1.0_r8
            endif
            dummy=consumpNO3*dts
            if (useNO3) then
              if(dummy.gt.(NO3local-BiolocalMinN))                      &
     &               facNO3=max(tinyno,(NO3local -BiolocalMinN)/dummy)
              Nlocal=Nlocal+NO3local
            else
              facNO3=1.0_r8
            endif
! CONSUMPTION FOR ALL N IS CONSIDERED IN facN-----------------------            
            dummy=consumpN*dts
            if(dummy.gt.(Nlocal-BiolocalMinN))                          &
     &               facN=max(tinyno,(Nlocal -BiolocalMinN)/dummy)
!-------------------------------------------------------------------
            dummy=consumpSi*dts
            if(dummy.gt.(Silocal-BiolocalMinSi))                        &
     &                facSi=max(tinyno,(Silocal -BiolocalMinSi)/dummy)
! Control for the fact that if NH4 is not available, Phyto can still
! utilize other sources.
            control_nut=min(facP,facNH4,facNO2,                         &
     &                      facNO3)
!           control_nut=min(facP,facN,facFeT)
            if((diatom(np).eq.1).and.(facSi.lt.control_nut)) then
              DiaBio3dLocal(ilimCTRL(np))=facSi*dts
            else
              DiaBio3dLocal(ilimCTRL(np))=control_nut*dts
            end if
            if(control_nut.lt.1.0d0) then
                 if((diatom(np).eq.1).and.(facSi.lt.control_nut)) then
                    PspecificPO4(np)=PspecificPO4(np)*facSi
                 else
                    PspecificPO4(np)=PspecificPO4(np)*control_nut
                 endif
                 consumpPO4 = PspecificPO4(np)
                 consumpSi  = PspecificPO4(np)*R_SiP(np)
                 consumpNO3 =                                           &
     &               (NO3limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
                 consumpNO2 =                                           &
     &               (NO2limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
                 consumpNH4 =                                           &
     &               (NH4limit(np)/Nlimit(np))*PspecificPO4(np)*R_NP(np)
            endif
!_________________________  d/dt's ___________________________________ 
            phyto(np) = phyto(np) + PspecificPO4(np)*dts 
            PP = PP + PspecificPO4(np)
            Nfix=Nfix+PspecificPO4(np)*R_NP(np)
            PPxdts = PPxdts + PspecificPO4(np)*dts
            NO3local = NO3local - consumpNO3*dts
            NO2local = NO2local - consumpNO2*dts
            NH4local = NH4local - consumpNH4*dts
            PO4local = PO4local - consumpPO4*dts
            Silocal = Silocal - consumpSi*dts
            DiaBio3dLocal(iPgrowth(np))=PspecificPO4(np)*dts
        DiaBio3dLocal(iPProd) = DiaBio3dLocal(iPProd) + consumpPO4*dts
        DiaBio3dLocal(iuptakePO4) = DiaBio3dLocal(iuptakePO4) +         &
     &                              consumpPO4*dts
        DiaBio3dLocal(iuptakeNH4) = DiaBio3dLocal(iuptakeNH4) +         &
     &                              consumpNH4*dts
        DiaBio3dLocal(iuptakeNO2) = DiaBio3dLocal(iuptakeNO2) +         &
     &                              consumpNO2*dts
        DiaBio3dLocal(iuptakeNO3) = DiaBio3dLocal(iuptakeNO3) +         &
     &                              consumpNO3*dts
        DiaBio3dLocal(iuptakeSi) = DiaBio3dLocal(iuptakeSi) +           &
     &                              consumpSi*dts
          enddo  !c FINAL END DO
!c ******************* END GROWTH PHYTO ******************************* 
! ******************* Grazing of Zoo on Phyt******************************
!c GRAZING: sum contributions of all zooplankton
!c GRAZING: sum contribution from all phytoplankton
!c sum all palatability*phyto and find phyto specific grazing rate
       allphyto=0.d0
       do nz=1,nzmax
         do np=1,npmax
           allphyto=allphyto+palat(np,nz)*phyto(np)
         enddo
         if (nz.eq.2) then
           allphyto=allphyto+palatzoo*zooP(1)
         endif
         if (allphyto.le.0.d0) allphyto=phygrazmin
         tmpz=max(0.d0,(allphyto-phygrazmin) )
         if (nz.eq.2) then
           if ((zooP(1)  .gt. BiolocalMinP)  .and.                      &
     &         (zooN(1)  .gt. BiolocalMinN)  .and.                      &
     &         (zooSi(1) .gt. BiolocalMinSi)) then
             grazzoo=grazemax(2)*(palatzoo*ZooP(1)/allphyto)*           &
     &          ((tmpz*tmpz)/((tmpz*tmpz)+(kgrazesat(2)*kgrazesat(2))))
             deltaZooP=grazzoo*ZooP(2)*dts 
             deltaZooN=grazzoo*ZooN(2)*dts 
             deltaZooSi=grazzoo*ZooSi(2)*dts
             ! check to ensure that there is enough phyto to graz
             ! control factor (control_graze) to prevents overgrazing
             if ((deltaZooP  .gt. (ZooP(1)  - BiolocalMinP)).or.        &
     &           (deltaZooN  .gt. (ZooN(1)  - BiolocalMinN)).or.        &
     &           (deltaZooSi .gt. (ZooSi(1) - BiolocalMinSi)))  then
               control_grazeZooP= 1.0_r8
               control_grazeZooN= 1.0_r8
               control_grazeZooSi= 1.0_r8
               if (deltaZooP.gt.(ZooP(1)-BiolocalMinP))                 &
     &           control_grazeZooP = (ZooP(1)-BiolocalMinP)/deltaZooP
               if (deltaZooN.gt.(ZooN(1)-BiolocalMinN))                 &
     &           control_grazeZooN = (ZooN(1)-BiolocalMinN)/deltaZooN
               if (deltaZooSi.gt.(ZooSi(1)-BiolocalMinSi))              &
     &           control_grazeZooSi =(ZooSi(1)-BiolocalMinSi)/deltaZooSi
               control_grazezoo=min(control_grazeZooP,                  &
     &                              control_grazeZooN,                  &
     &                              control_grazeZooSi)
               deltaZooP = deltaZooP * control_grazezoo
               deltaZooN = deltaZooN * control_grazezoo
               deltaZooSi = deltaZooSi * control_grazezoo
             endif  
! Phosphorous
             deltaZgrow = GrazeEffZoo*deltaZooP
             ZooP(1) = ZooP(1) -  deltaZooP
             ZooP(2) = ZooP(2) +  deltaZgrow
             deltaZloss=(1.0_r8-GrazeEffZoo)*deltaZooP
             POPlocal=POPlocal + ExportFracGraz(2)*deltaZloss
             DOPlocal=DOPlocal +(1.0_r8-ExportFracGraz(2))*deltaZloss
             DiaBio3dLocal(iZgrazP(1))=DiaBio3dLocal(iZgrazP(1))-       &
     &                                 deltaZooP
             DiaBio3dLocal(iZgrazP(2))=DiaBio3dLocal(iZgrazP(2))+       &
     &                                 deltaZgrow
             DiaBio3dLocal(iPOPexportZ)=DiaBio3dLocal(iPOPexportZ)+     &
     &                            ExportFracGraz(2)*deltaZloss
             DiaBio3dLocal(iDOPexportZ)=DiaBio3dLocal(iDOPexportZ)+     &
     &                            (1.0_r8-ExportFracGraz(2))*deltaZloss
! Nitrogen
             deltaZgrow = GrazeEffZoo*deltaZooN
             ZooN(1) = ZooN(1) -  deltaZooN
             ZooN(2) = ZooN(2) +  deltaZgrow
             deltaZloss=(1.0_r8-GrazeEffZoo)*deltaZooN
             PONlocal=PONlocal + ExportFracGraz(2)*deltaZloss
             DONlocal=DONlocal +(1.0_r8-ExportFracGraz(2))*deltaZloss
             DiaBio3dLocal(iZgrazN(1))=DiaBio3dLocal(iZgrazN(1))-       &
     &                                 deltaZooN
             DiaBio3dLocal(iZgrazN(2))=DiaBio3dLocal(iZgrazN(2))+       &
     &                                 deltaZgrow
             DiaBio3dLocal(iPONexportZ)=DiaBio3dLocal(iPONexportZ)+     &
     &                            ExportFracGraz(2)*deltaZloss
             DiaBio3dLocal(iDONexportZ)=DiaBio3dLocal(iDONexportZ)+     &
     &                            (1.0_r8-ExportFracGraz(2))*deltaZloss
! Silicate
             deltaZgrow = GrazeEffZoo*deltaZooSi
             ZooSi(1) = ZooSi(1) -  deltaZooSi
             ZooSi(2) = ZooSi(2) +  deltaZgrow
             deltaZloss=(1.0_r8-GrazeEffZoo)*deltaZooSi
             PSilocal=PSilocal + deltaZloss
             DiaBio3dLocal(iZgrazSi(1))=DiaBio3dLocal(iZgrazSi(1))-     &
     &                                 deltaZooSi
             DiaBio3dLocal(iZgrazSi(2))=DiaBio3dLocal(iZgrazSi(2))+     &
     &                                 deltaZgrow
             DiaBio3dLocal(iPSiexportZ)=DiaBio3dLocal(iPSiexportZ)+     &
     &                                  deltaZloss
           endif
         endif 
         do ip = 1, npmax
           np=irank(ip)
             ! SIGMOIDAL GRAZING SCHEME
             grazphy=grazemax(nz)*                                      &
     &        (palat(np,nz)*phyto(np)/allphyto)*                        &
     &        ((tmpz*tmpz)/((tmpz*tmpz)+(kgrazesat(nz)*kgrazesat(nz))))
             deltaP=grazphy*ZooP(nz)*dts
             if (deltaP.gt.phyto(np)-phymin) then
               deltaP=phyto(np)-phymin
             endif
!______________________________d/dt___________________________________
             phyto(np) = phyto(np) -  deltaP
             DiaBio3dLocal(iPgraz(np))=DiaBio3dLocal(iPgraz(np))-deltaP
             deltaPgrow = asseff(np,nz)*deltaP
             zooP(nz)  = zooP(nz)  +  deltaPgrow
             zooN(nz)  = zooN(nz)  + (deltaPgrow*R_NP(np))
             zooSi(nz) = zooSi(nz) + (deltaPgrow*R_SiP(np))
             DiaBio3dLocal(iZgrazP(nz))=DiaBio3dLocal(iZgrazP(nz))+     &
     &                                 deltaPgrow
             DiaBio3dLocal(iZgrazN(nz))=DiaBio3dLocal(iZgrazN(nz))+     &
     &                                 deltaPgrow*R_NP(np)
             DiaBio3dLocal(iZgrazSi(nz))=DiaBio3dLocal(iZgrazSi(nz))+   &
     &                                 deltaPgrow*R_SiP(np)
             if (DiaBio3dLocal(iZgrazSi(nz)).lt.0.0_r8) then
             end if
             deltaPloss = (1.0_r8-asseff(np,nz))*deltaP
             val=ExportFracGraz(nz)*deltaPloss
             POPlocal  = POPlocal  +  val
             PONlocal  = PONlocal  + (val*R_NP(np))
!            note: all Si lost goes into PSi (no DOSi)
             PSilocal = PSilocal + (deltaPloss*R_SiP(np))
             DiaBio3dLocal(iPOPgraz)=DiaBio3dLocal(iPOPgraz)+           &
     &                               val
             DiaBio3dLocal(iPONgraz)=DiaBio3dLocal(iPONgraz)+           &
     &                               (val*R_NP(np))
             DiaBio3dLocal(iPSigraz)=DiaBio3dLocal(iPSigraz)+           &
     &                               (deltaPloss*R_SiP(np))
             val=(1.0_r8-ExportFracGraz(nz))*deltaPloss
             DOPlocal  = DOPlocal  +  val
             DONlocal  = DONlocal  + (val*R_NP(np))
             grz_phytoxdts=grz_phytoxdts+deltaP
             DiaBio3dLocal(iDOPgraz)=DiaBio3dLocal(iDOPgraz)+           &
     &                               val
             DiaBio3dLocal(iDONgraz)=DiaBio3dLocal(iDONgraz)+           &
     &                               (val*R_NP(np))
         enddo
       enddo
! ********************  END ZOO GRAZING **************************
! *****************  Phytoplankton mortality *********************
        do ip = 1, npmax
            np=irank(ip)
          if (phyto(np).gt.phymin) then
             deltaP=mortphy(np)*phyto(np)*dts
             if (deltaP.gt.(phyto(np)-phymin)) then
               control_mortphyto=(phyto(np)-phymin)/deltaP
               deltaP=deltaP*control_mortphyto
             endif
           phyto(np)=phyto(np)-deltaP
           totphy_pop=totphy_pop+deltaP*ExportFracP(np)
           totphy_pon=totphy_pon+deltaP*ExportFracP(np)*R_NP(np)
           totphy_posi=totphy_posi+deltaP*R_SiP(np)
           totphy_dop=totphy_dop+deltaP*(1.d0-ExportFracP(np))
           totphy_don=totphy_don+deltaP*(1.d0-ExportFracP(np))*R_NP(np)
           DiaBio3dLocal(iPmort(np))=-deltaP
           DiaBio3dLocal(iPOPexportP)=DiaBio3dLocal(iPOPexportP)+       &
     &                 deltaP*ExportFracP(np)
           DiaBio3dLocal(iPONexportP)=DiaBio3dLocal(iPONexportP)+       &
     &                 deltaP*ExportFracP(np)*R_NP(np)
           DiaBio3dLocal(iPSiexportP)=DiaBio3dLocal(iPSiexportP)+       &
     &                 deltaP*ExportFracP(np)*R_SiP(np)
           DiaBio3dLocal(iDOPexportP)=DiaBio3dLocal(iDOPexportP)+       &
     &                 deltaP*(1.d0-ExportFracP(np))
           DiaBio3dLocal(iDONexportP)=DiaBio3dLocal(iDONexportP)+       &
     &                 deltaP*(1.d0-ExportFracP(np))*R_NP(np)
          endif
        enddo
! ************************* Zooplankton mortality *************************
        mortZooPxdts=0.d0
        do nz = 1, nzmax   
           if ((zooP(nz).gt.BiolocalMinP).and.                          &
     &         (zooN(nz).gt.BiolocalMinN).and.                          &
     &         (zooSi(nz).gt.BiolocalMinSi)) then
             !CHECK TO ENSURE THAT ZOO=DEAD is not greater than that avail
             deltaZooP=mortzoo(nz)*zooP(nz)*dts
             deltaZooN=mortzoo(nz)*zooN(nz)*dts
             deltaZooSi=mortzoo(nz)*zooSi(nz)*dts
             if ((deltaZooP.gt.(zooP(nz)-BiolocalMinP)).or.             &
     &         (deltaZooN.gt.(zooN(nz)-BiolocalMinN)))  then
               control_mortzooP = 1.0_r8
               control_mortzooN = 1.0_r8
               control_mortzooSi = 1.0_r8
               if (deltaZooP.gt.(zooP(nz)-BiolocalMinP))                &
     &          control_mortzooP=(zooP(nz)-BiolocalMinP)/deltaZooP    
               if (deltaZooN.gt.(zooN(nz)-BiolocalMinN))                &
     &          control_mortzooN=(zooN(nz)-BiolocalMinN)/deltaZooN    
               if (deltaZooSi.gt.(zooSi(nz)-BiolocalMinSi))             &
     &          control_mortzooSi=(zooSi(nz)-BiolocalMinSi)/deltaZooSi
!               !take the least offensive difference between deltaZooX and ZooX 
!               !and use for control factor for each deltaZooX
               control_mortzoo=min(control_mortzooP,control_mortzooN)
               deltaZooP  = deltaZooP  * control_mortzoo
               deltaZooN  = deltaZooN  * control_mortzoo
              if (control_mortzooSi.lt.control_mortzoo) then
               deltaZooSi = deltaZooSi * control_mortzooSi
              else
               deltaZooSi = deltaZooSi * control_mortzoo
              endif
             endif
             zooP(nz) = zooP(nz) - deltaZooP
             mortZooPxdts = mortZooPxdts + deltaZooP 
             zooN(nz) = zooN(nz) - deltaZooN
             zooSi(nz)=zooSi(nz)- deltaZooSi
             totzoo_pop=totzoo_pop+deltaZooP*ExportFracZ(nz)
             totzoo_pon=totzoo_pon+deltaZooN*ExportFracZ(nz)
             totzoo_posi=totzoo_posi+deltaZooSi
             totzoo_dop=totzoo_dop+deltaZooP*(1.d0-ExportFracZ(nz))
             totzoo_don=totzoo_don+deltaZooN*(1.d0-ExportFracZ(nz))
           DiaBio3dLocal(iZmortP(nz))=-deltaZooP
           DiaBio3dLocal(iZmortN(nz))=-deltaZooN
           DiaBio3dLocal(iZmortSi(nz))=-deltaZooSi
           DiaBio3dLocal(iPOPexportZ)=DiaBio3dLocal(iPOPexportZ)+       &
     &                 deltaZooP*ExportFracZ(nz)
           DiaBio3dLocal(iPONexportZ)=DiaBio3dLocal(iPONexportZ)+       &
     &                 deltaZooN*ExportFracZ(nz)
           DiaBio3dLocal(iPSiexportZ)=DiaBio3dLocal(iPSiexportZ)+       &
     &                 deltaZooSi*ExportFracZ(nz)
           DiaBio3dLocal(iDOPexportZ)=DiaBio3dLocal(iDOPexportZ)+       &
     &                 deltaZooP*(1.d0-ExportFracZ(nz))
           DiaBio3dLocal(iDONexportZ)=DiaBio3dLocal(iDONexportZ)+       &
     &                 deltaZooN*(1.d0-ExportFracZ(nz))
           endif
        enddo
       !UPDATE PARTICULATES FROM PHYTO AND ZOO PARTIC & DISSLVD EXPORT 
        POPlocal  = POPlocal  + totzoo_pop + totphy_pop 
        PONlocal  = PONlocal  + totzoo_pon + totphy_pon
        PSilocal  = PSilocal  + totzoo_posi + totphy_posi
        DOPlocal  = DOPlocal  + totzoo_dop + totphy_dop
        DONlocal  = DONlocal  + totzoo_don + totphy_don
! ********************** DOM remineralization rates ********************
      if  (DOPlocal.gt.BiolocalMinP) then
          deltaDOPremin =  Kdop * DOPlocal *dts
          ! check to ensure that there is enough DOP to remnrlze
          if  (deltaDOPremin.gt.(DOPlocal-BiolocalMinP)) then
            control_reminDOP=((DOPlocal-BiolocalMinP)/(deltaDOPremin))
            deltaDOPremin=deltaDOPremin*control_reminDOP
          endif
          PO4local = PO4local + deltaDOPremin
          DOPlocal  = DOPlocal -deltaDOPremin
          DiaBio3dLocal(iDOPremin)=deltaDOPremin
      endif
      if  (DONlocal.gt.BiolocalMinN) then
          deltaDONremin =  Kdon * DONlocal *dts
          ! check to ensure that there is enough DOP to remnrlze
          if  (deltaDONremin.gt.(DONlocal-BiolocalMinN)) then
            control_reminDON=((DONlocal-BiolocalMinN)/(deltaDONremin))
            deltaDONremin=deltaDONremin*control_reminDON
          endif
          NH4local = NH4local + deltaDONremin
          DONlocal  = DONlocal -deltaDONremin
          DiaBio3dLocal(iDONremin)=deltaDONremin
      endif
! ********** remineralization rates for sinking particulates ************
      if (POPlocal.gt.BiolocalMinP) then
         deltapreminP  = Kpremin_P *POPlocal *dts
         if (deltapreminP.gt.(POPlocal-BiolocalMinP)) then
           control_preminP=(POPlocal-BiolocalMinP)/(deltapreminP)
           deltapreminP   = deltapreminP*control_preminP
           deltapreminP   = deltapreminP*control_preminP
         endif 
         PO4local = PO4local + deltapreminP
         POPlocal = POPlocal   - deltapreminP
         DiaBio3dLocal(iPOPremin)=deltapreminP
      endif
      if  (PONlocal.gt.BiolocalMinN) then
         deltapreminN  = Kpremin_N *PONlocal *dts
         if (deltapreminN.gt.(PONlocal-BiolocalMinN)) then
           control_preminN=(PONlocal-BiolocalMinN)/(deltapreminN)
           deltapreminN   = deltapreminN*control_preminN
           deltapreminN   = deltapreminN*control_preminN
         endif
         NH4local = NH4local + deltapreminN
         PONlocal = PONlocal   - deltapreminN
         DiaBio3dLocal(iPONremin)=deltapreminN
      endif
      if  (PSilocal.gt.BiolocalMinSi) then
         deltapreminSi = Kpremin_Si*PSilocal *dts
         if (deltapreminSi.gt.(PSilocal-BiolocalMinSi)) then
           control_preminSi=(PSilocal-BiolocalMinSi)/(deltapreminSi)
           deltapreminSi   = deltapreminSi*control_preminSi
           deltapreminSi   = deltapreminSi*control_preminSi
         endif
         Silocal =  Silocal  + deltapreminSi
         PSilocal = PSilocal   - deltapreminSi
         DiaBio3dLocal(iPSiremin)=deltapreminSi
      endif
! chemistry
! **!**************** NH4 -> NO2 -> NO3 by bacterial action ***********
       if (NO2local.gt.BiolocalMinN) then
          delNO3prod=Knitb*(1.d0-min(PARlocal/PAR0,1.d0))*NO2local*dts
          if (delNO3prod.gt.(NO2local-BiolocalMinN)) then
            control_n03prod=(NO2local-BiolocalMinN)/(delNO3prod)
            delNO3prod=delNO3prod*control_nprod
          endif
          NO3local = NO3local + delNO3prod
          NO2local = NO2local - delNO3prod
          DiaBio3dLocal(iNO3prod)= delNO3prod
       endif
       if (NH4local.gt.BiolocalMinN) then 
          delNO2prod=Knita*(1.d0-min(PARlocal/PAR0,1.d0))*NH4local*dts
!c        NO2prod =  knita*NH4local
          if (delNO2prod.gt.(NH4local-BiolocalMinN))       then
            control_n02prod=(NH4local-BiolocalMinN)/(delNO2prod)
            delNO2prod=delNO2prod*control_n02prod
          endif
          NO2local = NO2local + delNO2prod 
          NH4local = NH4local - delNO2prod
          DiaBio3dLocal(iNO2prod)= delNO2prod
       endif
! *********************  SINKING now in darwin.h************************
         if (debug) then
         endif
         do ip = 1, npmax
           if (phyto(ip) < 0) then 
             print *,'ip=',ip,': phyto(ip)=',phyto(ip)
             print *,'gone negative'
             stop
           endif
         enddo
         RETURN
         END SUBROUTINE DARWIN_PLANKTON
! ----------------------------------------------------------------------
         SUBROUTINE INDEXX(n,arr,indx)
! ----------------------------------------------------------------------
         INTEGER n,indx(n),M,NSTACK
         REAL arr(n)
         PARAMETER (M=7, NSTACK=50)
         INTEGER ii, indxt,ir,itemp,jj, jstack, kk, ll, istack(NSTACK)
         REAL a
! ----------------------------------------------------------------------
         DO jj=1,n
           indx(jj)=jj
         enddo
         jstack=0
         ll=1
         ir=n
    1    if(ir-ll.lt.M)then
           do jj=ll+1,ir
             indxt=indx(jj)
             a=arr(indxt)
             do ii=jj-1,ll,-1
               if(arr(indx(ii)).le.a)goto 2
               indx(ii+1)=indx(ii)
             enddo
             ii=ll-1
    2        indx(ii+1)=indxt
           enddo
           if(jstack.eq.0)return
           ir=istack(jstack)
           ll=istack(jstack-1)
           jstack=jstack-2
         else
           kk=(ll+ir)/2.0
           itemp=indx(kk)
           indx(kk)=indx(ll+1)
           indx(ll+1)=itemp
           if (arr(indx(ll)).gt.arr(indx(ir)))then
             itemp=indx(ll)
             indx(ll)=indx(ir)
             indx(ir)=itemp
           endif
           if(arr(indx(ll+1)).gt.arr(indx(ir)))then
             itemp=indx(ll+1)
             indx(ll+1)=indx(ir)
             indx(ir)=itemp
           endif
           if(arr(indx(ll)).gt.arr(indx(ll+1)))then
             itemp=indx(ll)
             indx(ll)=indx(ll+1)
             indx(ll+1)=itemp
           endif
           ii=ll+1
           jj=ir
           indxt=indx(ll+1)
           a=arr(indxt)
    3      continue
               ii=ii+1
           if(arr(indx(ii)).lt.a)goto 3
    4      continue
             jj=jj-1
           if(arr(indx(jj)).gt.a)goto 4
           if(jj.lt.ii)goto 5
           itemp=indx(ii)
           indx(ii)=indx(jj)
           indx(jj)=itemp
           goto 3
    5      indx(ll+1)=indx(jj)
           indx(jj)=indxt
           jstack=jstack+2
           if(jstack.gt.NSTACK)pause 'NSTACK too small in indexx'
           if(ir-ii+1.ge.jj-1)then
             istack(jstack)=ir
             istack(jstack-1)=ii
             ir=jj-1
           else
             istack(jstack)=jj-1
             istack(jstack-1)=ll
             ll=ii
           endif
         endif
         goto 1
         RETURN
         END SUBROUTINE INDEXX
! ----------------------------------------------------------------------
         SUBROUTINE RANK(n,indx,irank)
! ----------------------------------------------------------------------
         INTEGER n,indx(N),irank(N)
         INTEGER j
         do j=1,n
           irank(indx(j))=j
         enddo
         return
         END SUBROUTINE RANK
       END MODULE DARWIN_PLANKTON_MOD
