      MODULE DARWIN_RANDOM_MOD
      implicit none
      PRIVATE
      PUBLIC  :: DARWIN_RANDOM_INIT, DARWIN_RANDOM, DARWIN_RANDOM_NORMAL
      CONTAINS
!C $Header: /u/gcmpack/MITgcm_contrib/darwin/pkg/darwin/darwin_random.F,v 1.5 2008/02/08 15:34:31 jahn Exp $
!C $Name:  $
!c ==========================================================
!c SUBROUTINE DARWIN_RANDOM_INIT(seed)
!c initializes the random number generator
!c seed must be positive
!c NOTE: not thread-safe yet!!!
!c ==========================================================
!c 
      SUBROUTINE DARWIN_RANDOM_INIT(seed, myThid)
      USE mod_kinds
      USE mod_biology
      IMPLICIT NONE
!C     !INPUT/OUTPUT PARAMETERS:
!C     == Routine arguments ==
!C  myThid               :: thread number
      INTEGER seed
      INTEGER myThid
!C     !FUNCTIONS:
!C     == Functions ==
!Coj   these are needed for the Intel compiler, define the macro 1
!Coj   in your optfile if you want to use it
      real*4 RAND
      EXTERNAL RAND
!C     !LOCAL VARIABLES:
!C     == Local variables ==
!C     msgBuf    - Informational/error meesage buffer
      CHARACTER*(MAX_LEN_MBUF) msgBuf
      real(r8) RandNo
      INTEGER nrand
      INTEGER Iseed
      INTEGER IRand
      CHARACTER*16 random_name
      IF (myThid .GT. 1) THEN
        print *,'DARWIN_RANDOM_INIT: threading no supported'
        STOP 'ABNORMAL END: S/R DARWIN_RANDOM_INIT'
      END IF
      IF (seed .LE. 0) THEN
        print *,'DARWIN_RANDOM_INIT: seed must be positive'
      END IF
      Iseed = -seed
      RandNo = rand(Iseed)
      random_name = 'rand'
      RETURN 
      END SUBROUTINE DARWIN_RANDOM_INIT
!c ==========================================================
!c FUNCTION DARWIN_RANDOM()
!c returns a uniform random number between 0 and 1
!c ==========================================================
!c 
      FUNCTION DARWIN_RANDOM(myThid)
      USE mod_kinds
      USE mod_biology
      IMPLICIT NONE
!C     !INPUT/OUTPUT PARAMETERS:
!C     == Routine arguments ==
!C  DARWIN_RANDOM        :: uniform random number
!C  myThid               :: thread number
      real(r8) DARWIN_RANDOM
      INTEGER myThid
!C     !FUNCTIONS:
!C     == Functions ==
      real*4 RAND
      EXTERNAL RAND
!C     !LOCAL VARIABLES:
!C     == Local variables ==
      INTEGER Iseed
      IF (myThid .GT. 1) THEN
        print *,'DARWIN_RANDOM: threading no supported'
        STOP 'ABNORMAL END: S/R DARWIN_RANDOM'
      END IF
      Iseed = 0
      darwin_random = rand(Iseed)
      RETURN 
      END FUNCTION DARWIN_RANDOM
!c ==========================================================
!c FUNCTION DARWIN_RANDOM_NORMAL()
!c returns a normally distributed random number with mean 0 and stddev 1
!c ==========================================================
!c 
      FUNCTION DARWIN_RANDOM_NORMAL(myThid)
      USE mod_kinds
      USE mod_biology
      IMPLICIT NONE
!C     !INPUT/OUTPUT PARAMETERS:
!C     == Routine arguments ==
!C  DARWIN_RANDOM_NORMAL :: normally distributed random number
!C  myThid               :: thread number
      real(r8) DARWIN_RANDOM_NORMAL
      INTEGER myThid
!C     !FUNCTIONS:
!C     == Functions ==
      real*4 RAND
      EXTERNAL RAND
!C     !LOCAL VARIABLES:
!C     == Local variables ==
      INTEGER Iseed
      real*8 uniform
      real*8 normal
      IF (myThid .GT. 1) THEN
        print *,'DARWIN_RANDOM: threading no supported'
        STOP 'ABNORMAL END: S/R DARWIN_RANDOM'
      END IF
      Iseed = 0
      uniform = rand(Iseed)
      CALL invnormal(normal, uniform, 0.d0, 1.d0)
      darwin_random_normal = normal
      RETURN 
      END FUNCTION DARWIN_RANDOM_NORMAL
!c ==========================================================
      END MODULE DARWIN_RANDOM_MOD
