      MODULE mod_ncparam
!
!svn $Id: mod_ncparam.F 366 2009-07-09 04:41:00Z arango $
!================================================== Hernan G. Arango ===
!  Copyright (c) 2002-2009 The ROMS/TOMS Group                         !
!    Licensed under a MIT/X style license                              !
!    See License_ROMS.txt                                              !
!=======================================================================
!                                                                      !
!  This MODULE contains all the variables associated with input and    !
!  output  NetCDF  files.  The IO model is very generic and easy to    !
!  change or expand.  The NetCDF files can be in any language.  All    !
!  the IO information is managed using the following variables:        !
!                                                                      !
!  Vname      Input/output variables names and attributes:             !
!               Vname(1,*)  => field variable name.                    !
!               Vname(2,*)  => long-name attribute.                    !
!               Vname(3,*)  => units attribute.                        !
!               Vname(4,*)  => field type attribute.                   !
!               Vname(5,*)  => associated time variable name.          !
!  Tname      Input/output associated time variables names.            !
!                                                                      !
!  Cinfo      Input/output file names associated with each field       !
!                                                                      !
!  Linfo      Input/output fields logical information:                 !
!               Linfo(1,*)  => switch indicating grided data.          !
!               Linfo(2,*)  => switch indicating time cycling.         !
!               Linfo(3,*)  => switch indicating only one-time         !
!                              record available.                       !
!               Linfo(4,*)  => switch indication special record        !
!                              processing (like tides)                 !
!                                                                      !
!  Iinfo      Input/output fields integer information:                 !
!               Iinfo(1,*)  => variable grid type.                     !
!               Iinfo(2,*)  => field variable NetCDF ID.               !
!               Iinfo(3,*)  => associated time variable NetCDF ID.     !
!               Iinfo(4,*)  => number of time records.                 !
!               Iinfo(5,*)  => size of first  spatial dimension.       !
!               Iinfo(6,*)  => size of second spatial dimension.       !
!               Iinfo(7,*)  => size of third  spatial dimension.       !
!               Iinfo(8,*)  => rolling two-time levels index.          !
!               Iinfo(9,*)  => latest processed time record .          !
!                                                                      !
!  Finfo      Input/output field floating-point information:           !
!               Finfo(1,*)  => Starting time (days) of data.           !
!               Finfo(2,*)  => Ending time (days) of data.             !
!               Finfo(3,*)  => Data time lower bound (days) enclosing  !
!                                model starting time.                  !
!               Finfo(4,*)  => Data time upper bound (days) enclosing  !
!                                model starting time.                  !
!               Finfo(5,*)  => length (days) of time cycling.          !
!               Finfo(6,*)  => Scale to convert time to day units.     !
!               Finfo(7,*)  => latest monotonic time (sec).            !
!               Finfo(8,*)  => minimum value for current data.         !
!               Finfo(9,*)  => maximum value for current data.         !
!  Fscale     Scale to convert input data to model units.              !
!  Fpoint     Latest two-time records of input point data.             !
!  Tintrp     Time (sec) of latest field snapshots used for            !
!               interpolation.                                         !
!  Vtime      Latest two-time values of processed input data.          !
!                                                                      !
!=======================================================================
!
        USE mod_param        
        implicit none
!
!  Maximum number of variables in a generic NetCDF file (MV) and
!  maximum number of variables in information arrays (NV).
!
        integer, parameter :: MV = 3000
        integer, parameter :: NV = 3000
!
!  Input/output grid-type variables.
!
        integer, parameter :: p2dvar = 1         ! 2D PSI-variable
        integer, parameter :: r2dvar = 2         ! 2D RHO-variable
        integer, parameter :: u2dvar = 3         ! 2D U-variable
        integer, parameter :: v2dvar = 4         ! 2D V-variable
        integer, parameter :: p3dvar = 5         ! 3D PSI-variable
        integer, parameter :: r3dvar = 6         ! 3D RHO-variable
        integer, parameter :: u3dvar = 7         ! 3D U-variable
        integer, parameter :: v3dvar = 8         ! 3D V-variable
        integer, parameter :: w3dvar = 9         ! 3D W-variable
        integer, parameter :: b3dvar = 10        ! 3D BED-sediment
!
!  Number of horizontal interior and boundary water points.
!
        integer  :: Nxyp(Ngrids)        ! PSI water points
        integer  :: Nxyr(Ngrids)        ! RHO water points
        integer  :: Nxyu(Ngrids)        ! U water points
        integer  :: Nxyv(Ngrids)        ! V water points
!
!  Number of horizontal interior water points only.
!
        integer  :: NwaterR(Ngrids)     ! RHO water points
        integer  :: NwaterU(Ngrids)     ! U water points
        integer  :: NwaterV(Ngrids)     ! V water points
!
!  Lower and upper bound ranges for RHO-type variables for processing
!  state vector and observations.
!
        integer, dimension(Ngrids) :: rILB
        integer, dimension(Ngrids) :: rIUB
        integer, dimension(Ngrids) :: rJLB
        integer, dimension(Ngrids) :: rJUB
!
        real(r8), dimension(Ngrids) :: rXmin
        real(r8), dimension(Ngrids) :: rXmax
        real(r8), dimension(Ngrids) :: rYmin
        real(r8), dimension(Ngrids) :: rYmax
!
!  Lower and upper bound ranges for U-type variables for processing
!  state vector and observations.
!
        integer, dimension(Ngrids) :: uILB
        integer, dimension(Ngrids) :: uIUB
        integer, dimension(Ngrids) :: uJLB
        integer, dimension(Ngrids) :: uJUB
!
        real(r8), dimension(Ngrids) :: uXmin
        real(r8), dimension(Ngrids) :: uXmax
        real(r8), dimension(Ngrids) :: uYmin
        real(r8), dimension(Ngrids) :: uYmax
!
!  Lower and upper bound ranges for V-type variables for processing
!  state vector and observations.
!
        integer, dimension(Ngrids) :: vILB
        integer, dimension(Ngrids) :: vIUB
        integer, dimension(Ngrids) :: vJLB
        integer, dimension(Ngrids) :: vJUB
!
        real(r8), dimension(Ngrids) :: vXmin
        real(r8), dimension(Ngrids) :: vXmax
        real(r8), dimension(Ngrids) :: vYmin
        real(r8), dimension(Ngrids) :: vYmax
!
!  Lower and upper bound ranges
!
!  Switches indicating which variables are written to output files.
!
        logical  :: Hout(NV,Ngrids) ! history file switches
        logical  :: Sout(NV,Ngrids) ! station file switches
!
!  Input/output identification indices.
!
        integer  :: idXgrd = -1   ! XI-grid position
        integer  :: idYgrd = -2   ! ETA-grid position
        integer  :: idZgrd = -3   ! S-grid position
        integer  :: iddpth = -4   ! depth
        integer  :: idglon = -5   ! longitude
        integer  :: idglat = -6   ! latitude
        integer  :: idAice        ! fraction of cell covered by ice
        integer  :: idbath        ! bathymetry
        integer  :: idCfra        ! cloud fraction
        integer  :: idCosW        ! COS(omega(k)*t)
        integer  :: idCos2        ! COS(omega(k)*t)*COS(omega(l)*t)
        integer  :: idDano        ! density anomaly
        integer  :: idDiff(2)     ! temperature and salinity diffusion
        integer  :: iddQdT        ! heat flux sensitivity to SST
        integer  :: idevap        ! evaporation rate
        integer  :: idFsur        ! free-surface
        integer  :: idFsuD        ! detided free-surface
        integer  :: idFsuH        ! free-surface tide harmonics
        integer  :: idGhat(2)     ! KPP nonlocal transport
        integer  :: idHbbl        ! depth of bottom boundary layer
        integer  :: idHice        ! depth of ice cover
        integer  :: idHsbl        ! depth of surface boundary layer
        integer  :: idHsno        ! depth of snow cover
        integer  :: idKhor        ! convolution horizontal diffusion
        integer  :: idKver        ! convolution vertical diffusion
        integer  :: idLdwn        ! downwelling longwave radiation flux
        integer  :: idLhea        ! net latent heat flux
        integer  :: idLrad        ! net longwave radiation flux
        integer  :: idMadH        ! ADM interpolation weights
        integer  :: idMOMi        ! Initial model-observation misfit
        integer  :: idMOMf        ! final model-observation misfit
        integer  :: idMtke        ! turbulent kinetic energy
        integer  :: idMtls        ! turbulent length scale
        integer  :: idNLmi        ! initial NLM at observation locations
        integer  :: idNLmo        ! NLM at observations locations
        integer  :: idNobs        ! number of observations
        integer  :: idObsD        ! observations depth
        integer  :: idObsS        ! observations screening scale
        integer  :: idObsT        ! observations time
        integer  :: idObsX        ! observations X-grid location
        integer  :: idObsY        ! observations Y-grid location
        integer  :: idObsZ        ! observations Z-grid location
        integer  :: idOday        ! observations survey time
        integer  :: idOerr        ! observations error
        integer  :: idOtyp        ! observations type
        integer  :: idOval        ! observations value
        integer  :: idOvar        ! observations global variance
        integer  :: idOvel        ! omega vertical velocity
        integer  :: idQair        ! surface air humidity
        integer  :: idPair        ! surface air pressure
        integer  :: idPbar        ! streamfunction
        integer  :: idRdir        ! river runoff direction
        integer  :: idRepo        ! river runoff ETA-positions
        integer  :: idRflg        ! river runoff flag
        integer  :: idRtra        ! river runoff mass transport
        integer  :: idRuct        ! RHS of U-momentum coupling term
        integer  :: idRu2d        ! RHS of 2D U-momentum
        integer  :: idRu3d        ! RHS of total U-momentum
        integer  :: idRvct        ! RHS of V-momentum coupling term
        integer  :: idRv2d        ! RHS of 2D V-momentum
        integer  :: idRv3d        ! RHS of total V-momentum
        integer  :: idRxpo        ! river runoff XI-positions
        integer  :: idRvsh        ! river runoff transport profile
        integer  :: idRwet        ! wet/dry mask on RHO-points
        integer  :: idRzet        ! RHS of free-surface
        integer  :: idrain        ! rainfall rate
        integer  :: idSdif        ! vertical S-diffusion coefficient
        integer  :: idSinW        ! SIN(omega(k)*t)
        integer  :: idSin2        ! SIN(omega(k)*t)*SIN(omega(l)*t)
        integer  :: idSrad        ! net shortwave radiation flux
        integer  :: idSSHc        ! SSH climatology
        integer  :: idSSHe        ! SSH error variance
        integer  :: idSSHo        ! SSH observations
        integer  :: idSSSc        ! SSS climatology
        integer  :: idSSTc        ! SST climatology
        integer  :: idSSTe        ! SST error variance
        integer  :: idSSTo        ! SST observations
        integer  :: idShea        ! net sensible heat flux
        integer  :: idSWCW        ! SIN(omega(k)*t)*COS(omega(l)*t)
        integer  :: idsfwf        ! surface freswater flux
        integer  :: idTLmo        ! TLM at observation locations
        integer  :: idTair        ! surface air temperature
        integer  :: idTdif        ! vertical T-diffusion coefficient
        integer  :: idTice        ! temperature of ice surface
        integer  :: idtime        ! ocean time
        integer  :: idTper        ! tidal period
        integer  :: idTvan        ! tidal current angle
        integer  :: idTvma        ! maximum tidal current
        integer  :: idTvmi        ! minimum tidal current
        integer  :: idTvph        ! tidal current phase
        integer  :: idTzam        ! tidal elevation amplitude
        integer  :: idTzph        ! tidal elevation phase
        integer  :: idu2dA        ! accumulated 2D U-velocity
        integer  :: idU2rs        ! 2D total U-radiation stress
        integer  :: idU3rs        ! 3D total U-radiation stress
        integer  :: idU2Sd        ! 2D U-Stokes drift velocity
        integer  :: idU3Sd        ! 3D U-Stokes drift velocity
        integer  :: idUads        ! 3D U-velocity adjoint sensitivity
        integer  :: idUair        ! surface U-wind
        integer  :: idUbar        ! 2D U-velocity
        integer  :: idUbas        ! 2D U-velocity adjoint sensitivity
        integer  :: idUbcl        ! 2D U-velocity climatology
        integer  :: idUbcs        ! bottom max U-momentum-wave stress
        integer  :: idUbed        ! bed load U-direction
        integer  :: idUbms        ! bottom U-momentum stress
        integer  :: idUbot        ! bed wave orbital U-velocity
        integer  :: idUbrs        ! bottom U-current stress
        integer  :: idUbtf        ! 2D U-velocity impulse forcing
        integer  :: idUbur        ! bottom U-velocity above bed
        integer  :: idUbws        ! bottom U-wave stress
        integer  :: idUclm        ! 3D U-velocity climatology
        integer  :: idUfx1        ! time averaged U-flux for 2D
        integer  :: idUfx2        ! time averaged U-flux for 3D
        integer  :: idUice        ! ice U-velocity
        integer  :: idUobs        ! 3D U-velocity observations
        integer  :: idUsms        ! surface U-momentum stress
        integer  :: idUsur        ! surface U-velocity observations
        integer  :: idUtlf        ! 3D U-velocity impulse forcing
        integer  :: idUVer        ! 3D velocity error variance
        integer  :: idUVse        ! surface velocity error variance
        integer  :: idUvel        ! 3D U-velocity
        integer  :: idUwet        ! wet/dry mask on U-points
        integer  :: idu2dD        ! detided 2D U-velocity
        integer  :: idu2dH        ! 2D U-velocity tide harmonics
        integer  :: idu3dD        ! detided 3D U-velocity
        integer  :: idu3dH        ! 3D U-velocity tide harmonics
        integer  :: idV2rs        ! 2D total V-radiation stress
        integer  :: idV3rs        ! 3D total V-radiation stress
        integer  :: idV2Sd        ! 2D U-Stokes drift velocity
        integer  :: idV3Sd        ! 3D U-Stokes drift velocity
        integer  :: idVads        ! 3D V-velocity adjoint sensitivity
        integer  :: idVair        ! surface V-wind
        integer  :: idVbar        ! 2D V-velocity
        integer  :: idVbas        ! 2D V-velocity adjoint sensitivity
        integer  :: idVbcl        ! 2D V-velocity climatology
        integer  :: idVbcs        ! bottom max V-current-wave stress
        integer  :: idVbed        ! bed load V-direction
        integer  :: idVbms        ! bottom V-momentum stress
        integer  :: idVbot        ! bed wave orbital V-velocity
        integer  :: idVbrs        ! bottom V-current stress
        integer  :: idVbtf        ! 2D V-velocity impulse forcing
        integer  :: idVbvr        ! bottom V-velocity above bed
        integer  :: idVbws        ! bottom V-wave stress
        integer  :: idVclm        ! 3D V-velocity climatology
        integer  :: idVfx1        ! 2D momentum time-averaged V-flux
        integer  :: idVfx2        ! 3D momentum time-averaged V-flux
        integer  :: idVice        ! ice V-velocity
        integer  :: idVmLS        ! vertical mixing length scale
        integer  :: idVmKK        ! Kinetic energy vertical mixing
        integer  :: idVmKP        ! Length scale vertical mixing
        integer  :: idVobs        ! 3D V-velocity observations
        integer  :: idVsms        ! surface V-momentum stress
        integer  :: idVsur        ! surface V-velocity observations
        integer  :: idVtlf        ! 3D V-velocity impulse forcing
        integer  :: idVvel        ! 3D V-velocity
        integer  :: idVvis        ! vertical viscosity coefficient
        integer  :: idVwet        ! wet/dry mask on V-points
        integer  :: idv2dD        ! detided 2D U-velocity
        integer  :: idv2dH        ! 2D U-velocity tide harmonics
        integer  :: idv3dD        ! detided 3D U-velocity
        integer  :: idv3dH        ! 3D U-velocity tide harmonics
        integer  :: idW2xx        ! 2D radiation stress, Sxx-component
        integer  :: idW2xy        ! 2D radiation stress, Sxy-component
        integer  :: idW2yy        ! 2D radiation stress, Syy-component
        integer  :: idW3xx        ! 3D radiation stress, Sxx-component
        integer  :: idW3xy        ! 3D radiation stress, Sxy-component
        integer  :: idW3yy        ! 3D radiation stress, Syy-component
        integer  :: idW3zx        ! 3D radiation stress, Szx-component
        integer  :: idW3zy        ! 3D radiation stress, Szy-component
        integer  :: idWamp        ! wind-induced wave amplitude
        integer  :: idWbrk        ! wind-induced wave breaking
        integer  :: idWdis        ! wind-induced wave dissipation
        integer  :: idWdir        ! wind-induced wave direction
        integer  :: idWlen        ! wind-induced wave length
        integer  :: idWptp        ! wind-induced surface wave period
        integer  :: idWpbt        ! wind-induced bottom wave period
        integer  :: idWorb        ! wind-induced wave orbital velocity
        integer  :: idWvel        ! true vertical velocity
        integer  :: idZads        ! Free-surface adjoint sensitivity
        integer  :: idZtlf        ! Free-surface impulse forcing
        integer, allocatable :: idRtrc(:)    ! river runoff for tracers
        integer, allocatable :: idTads(:)    ! tracers adjoint sentivity
        integer, allocatable :: idTbot(:)    ! bottom flux for tracers
        integer, allocatable :: idTbry(:,:)  ! tracers boundary
        integer, allocatable :: idTclm(:)    ! tracers climatology
        integer, allocatable :: idTerr(:)    ! tracers error variance
        integer, allocatable :: idTobs(:)    ! tracers observations
        integer, allocatable :: idTsur(:)    ! surface flux for tracers
        integer, allocatable :: idTtlf(:)    ! tracers impulse forcing
        integer  :: idU2bc(4)      ! 2D U-velocity boundary conditions
        integer  :: idU3bc(4)      ! 3D U-velocity boundary conditions
        integer  :: idV2bc(4)      ! 2D V-velocity boundary conditions
        integer  :: idV3bc(4)      ! 3D V-velocity boundary conditions
        integer  :: idZbry(4)      ! free-surface boundary conditions
!
!  Time-averaged quadratic terms IDs.
!
        integer  :: idU2av                    ! <ubar*ubar>
        integer  :: idV2av                    ! <vbar*vbar>
        integer  :: idZZav                    ! <zeta*zeta>
        integer  :: idHUav                    ! <Huon>
        integer  :: idHVav                    ! <Hvom>
        integer  :: idUUav                    ! <u*u>
        integer  :: idUVav                    ! <u*v>
        integer  :: idVVav                    ! <v*v>
        integer, allocatable :: iHUTav(:)     ! <Huon*t> for active tracers
        integer, allocatable :: iHVTav(:)     ! <Hvom*t> for active tracers
        integer, allocatable :: idTTav(:)     ! <t*t> for active tracers
        integer, allocatable :: idUTav(:)     ! <u*t> for active tracers
        integer, allocatable :: idVTav(:)     ! <v*t> for active tracers
        integer :: icae, iloc
!
!  Biological 1D diagnostic variable IDs.
!
        integer, allocatable :: idDar1d(:)    ! 1D biological parameters
        integer, allocatable :: idDar2d(:)    ! 2D biological parameters
!
!       set arguments for idDar1d
        integer :: iSeedPT = 1                ! Seed for phyto type
        integer :: iSeedPP = 2                ! Seed for phyto parameters
!       set arguments for idDar2d
        integer :: iSedPOP = 1                ! Sediment layer for POP
        integer :: iSedPON = 2                ! Sediment layer for PON
        integer :: iSedPOFe = 3                ! Sediment layer for POFe
        integer :: iSedPOSi = 4                ! Sediment layer for POSi
!
!  Biological 2D diagnostic variable IDs.
!
        integer, allocatable :: iDbio2(:)     ! 2D biological terms
!
!  Biological 3D diagnostic variable IDs.
!
        integer, allocatable :: iDbio3(:)     ! 3D biological terms
        integer, allocatable :: iPgrowth(:)  ! Phytoplankton growth in PO4
        integer, allocatable :: iPgraz(:)      ! Phytoplankton loss due to grazing
        integer, allocatable :: iPmort(:)      ! Phytoplankton loss due to mortality
        integer, allocatable :: iPsink(:)   ! Phytoplankton sinking flux divergence
        integer, allocatable :: iZgrazP(:)  ! Zooplankton Phosphorous gain due to grazing
        integer, allocatable :: iZgrazN(:)  ! Zooplankton Nitrogen gain due to grazing
        integer, allocatable :: iZgrazSi(:) ! Zooplankton Silica gain due to grazing
        integer, allocatable :: iZmortP(:)     ! Zooplankton Phosphorous loss due to mortality
        integer, allocatable :: iZmortN(:)     ! Zooplankton Nitrogen loss due to mortality
        integer, allocatable :: iZmortSi(:)    ! Zooplankton Silica loss due to mortality
        integer :: iuptakePO4        ! Phytoplankton uptake of PO4
        integer :: iuptakeNH4        ! Phytoplankton uptake of NH4
        integer :: iuptakeNO2        ! Phytoplankton uptake of NO2
        integer :: iuptakeNO3        ! Phytoplankton uptake of NO3
        integer :: iuptakeSi         ! Phytoplankton uptake of Si
        integer :: iPOPgraz           ! Particulate Phosphorous gain due to grazing
        integer :: iPONgraz           ! Particulate Nitrogen gain due to grazing
        integer :: iPSigraz           ! Particulate Silica gain due to grazing
        integer :: iDOPgraz           ! Dissolved Phos. gain due to grazing
        integer :: iDONgraz           ! Dissolved Nit. gain due to grazing
        integer :: iPOPexportP        ! Part. Phos. gain due to Phyt. mortality
        integer :: iPONexportP        ! Part. Nit. gain due to phyt. mortality
        integer :: iPSiexportP        ! Part. Silica gain due to phyt. mortality
        integer :: iDOPexportP        ! Diss. Phos. gain due to phyt. mortality
        integer :: iDONexportP        ! Diss. Nit. gain due to phyt. mortality
        integer :: iPOPexportZ        ! Part. Phos. gain due to zoo.  mortality
        integer :: iPONexportZ        ! Part. Nit. gain due to zoo.  mortality
        integer :: iPSiexportZ        ! Part. Silica gain due to zoo.  mortality
        integer :: iDOPexportZ        ! Diss. Phos. gain due to zoo.  mortality
        integer :: iDONexportZ        ! Diss. Nit. gain due to zoo.  mortality
        integer :: isinkPOP           ! Part. Phos. sinking flux divergence
        integer :: isinkPON           ! Part. Nit. sinking flux divergence
        integer :: isinkPSi           ! Part. Silica sinking flux divergence
        integer :: iPOPremin          ! Part. Phos. loss due to remin.
        integer :: iPONremin          ! Part. Nit. loss due to remin.
        integer :: iPSiremin          ! Part. Silica loss due to remin.
        integer :: iDOPremin          ! Diss. Phos. loss due to remin.
        integer :: iDONremin          ! Diss. Nit. loss due to remin.
        integer :: iNO3prod           ! production of NO3 from NO2
        integer :: iNO2prod           ! production of NO2 from NH4
        integer, allocatable :: ilimCTRL(:)! control factor in nut limitation
        integer, allocatable :: ilimI(:)   ! Light limitation
        integer, allocatable :: ilimN(:)   ! Nitrogen limitation
        integer, allocatable :: ilimP(:)   ! Phosphorous limitation
        integer, allocatable :: ilimSi(:)  ! Silica limitation
        integer, allocatable :: ilimT(:)   ! Temperature limitation
        integer :: iPProd             ! Primary production
!
!  Tracer/Momentum Diagnostic variable IDs.
!
        integer, allocatable :: idDtrc(:,:)   ! tracers terms
        integer, allocatable :: idDu2d(:)     ! 2D u-momentum terms
        integer, allocatable :: idDv2d(:)     ! 2D v-momentum terms
        integer, allocatable :: idDu3d(:)     ! 3D u-momentum terms
        integer, allocatable :: idDv3d(:)     ! 3D v-momentum terms
!
!  Assimilation state variables indices (order is important).
!
        integer  :: isFsur = 1                ! free-surface
        integer  :: isUbar = 2                ! 2D U-velocity
        integer  :: isVbar = 3                ! 2D V-velocity
        integer  :: isUvel = 4                ! 3D U-velocity
        integer  :: isVvel = 5                ! 3D V-velocity
        integer  :: isUstr                    ! surface u-stress
        integer  :: isVstr                    ! surface v-stress
        integer, allocatable :: isTsur(:)     ! surface tracer flux
        integer, allocatable :: isTvar(:)     ! tracers
        integer, allocatable :: idSvar(:)     ! state vector indices
        integer, allocatable :: idSbry(:)     ! state boundaries indices
!
!  Input/Output NetCDF files IDs.
!
        integer  :: ncADJid(Ngrids)     ! input/output adjoint
        integer  :: ncADSid(Ngrids)     ! input adjoint sensitivity
        integer  :: ncAVGid(Ngrids)     ! output averages
        integer  :: ncBRYid(Ngrids)     ! input boundary conditions
        integer  :: ncCLMid(Ngrids)     ! input climatology
        integer  :: ncDIAid(Ngrids)     ! output diagnostics
        integer  :: ncFLTid(Ngrids)     ! output floats
        integer  :: ncERRid(Ngrids)     ! output 4DVar posterior error
        integer  :: ncFRCid(NV,Ngrids)  ! input forcing
        integer  :: ncFWDid(Ngrids)     ! forward solution
        integer  :: ncGRDid(Ngrids)     ! input grid
        integer  :: ncGSTid(Ngrids)     ! input/output GST restart
        integer  :: ncHISid(Ngrids)     ! output history
        integer  :: ncHSSid(Ngrids)     ! input/output Hessian vectors
        integer  :: ncINIid(Ngrids)     ! input/output NLM initial
        integer  :: ncIRPid(Ngrids)     ! input/output RPM initial
        integer  :: ncITLid(Ngrids)     ! input/output TLM initial
        integer  :: ncLCZid(Ngrids)     ! input/output Lanczos vectors
        integer  :: ncMODid(Ngrids)     ! output 4DVAR fields
        integer  :: ncNRMid(4,Ngrids)   ! input/output covariance norm
        integer  :: ncOBSid(Ngrids)     ! input/output observations
        integer  :: ncRSTid(Ngrids)     ! input/output restart
        integer  :: ncSSHid(Ngrids)     ! SSH observations
        integer  :: ncSSTid(Ngrids)     ! SST observations
        integer  :: ncSTAid(Ngrids)     ! output stations
        integer  :: ncTIDEid(Ngrids)    ! input/output tide forcing
        integer  :: ncTLFid(Ngrids)     ! input/output TLM/RPM impulses
        integer  :: ncTLMid(Ngrids)     ! input/output tangent linear
        integer  :: ncTOBSid(Ngrids)    ! tracer observations
        integer  :: ncVOBSid(Ngrids)    ! currents observations
        integer  :: ncVSURid(Ngrids)    ! surface currents observations
        integer  :: idefADJ(Ngrids)     ! adjoint file creation flag
        integer  :: idefAVG(Ngrids)     ! averages file creation flag
        integer  :: idefDIA(Ngrids)     ! diagnostics file creation flag
        integer  :: idefHIS(Ngrids)     ! history file creation flag
        integer  :: idefTLM(Ngrids)     ! tangent file creation flag
!
!  Output NetCDF variables IDs.
!
        integer, allocatable :: idTvar(:)     ! tracers variables
        integer, allocatable :: adjTid(:,:)   ! adjoint tracers IDs
        integer, allocatable :: avgTid(:,:)   ! averages tracers IDs
        integer, allocatable :: errTid(:,:)   ! error tracer IDs
        integer, allocatable :: fltTid(:,:)   ! floats tracers IDs
        integer, allocatable :: hisTid(:,:)   ! history tracers IDs
        integer, allocatable :: hssTid(:,:)   ! Hessian tracers IDs
        integer, allocatable :: iniTid(:,:)   ! initial NLM tracers IDs
        integer, allocatable :: irpTid(:,:)   ! initial RPM tracers IDs
        integer, allocatable :: itlTid(:,:)   ! initial TLM tracers IDs
        integer, allocatable :: lczTid(:,:)   ! Lanczos tracers IDs
        integer, allocatable :: obsTid(:,:)   ! observations tracers IDs
        integer, allocatable :: rstTid(:,:)   ! restart tracers IDs
        integer, allocatable :: staTid(:,:)   ! stations tracers IDs
        integer, allocatable :: tlfTid(:,:)   ! TLM impulse tracers IDs
        integer, allocatable :: tlmTid(:,:)   ! tangent tracers IDs
        integer  :: adjVid(NV,Ngrids)    ! adjoint variables IDs
        integer  :: avgVid(NV,Ngrids)    ! averages variables IDs
        integer  :: diaVid(NV,Ngrids)    ! diagnostics variables IDs
        integer  :: errVid(NV,Ngrids)    ! error variables IDs
        integer  :: fltVid(-6:NV,Ngrids) ! floats variables IDs
        integer  :: hisVid(NV,Ngrids)    ! history variables IDs
        integer  :: hssVid(NV,Ngrids)    ! Hessian variables IDs
        integer  :: iniVid(NV,Ngrids)    ! initial NLM variables IDs
        integer  :: irpVid(NV,Ngrids)    ! initial RPM variables IDs
        integer  :: itlVid(NV,Ngrids)    ! initial TLM variables IDs
        integer  :: lczVid(NV,Ngrids)    ! Lanczos variables IDs
        integer  :: modVid(NV,Ngrids)    ! 4DVAR variables IDs
        integer  :: nrmVid(4,NV,Ngrids)  ! norm variables IDs
        integer  :: obsVid(NV,Ngrids)    ! observations variables IDs
        integer  :: rstVid(NV,Ngrids)    ! restart variables IDs
        integer  :: staVid(NV,Ngrids)    ! stations variables IDs
        integer  :: tideVid(NV,Ngrids)   ! tide variables IDs
        integer  :: tlfVid(NV,Ngrids)    ! TLM impulse variables IDs
        integer  :: tlmVid(NV,Ngrids)    ! tangent variables IDs
        integer  :: tADJindx(Ngrids)     ! adjoint time record index
        integer  :: tAVGindx(Ngrids)     ! averages time record index
        integer  :: tDIAindx(Ngrids)     ! diagnostics time record index
        integer  :: tERRindx(Ngrids)     ! error time record index
        integer  :: tFLTindx(Ngrids)     ! floats time record index
        integer  :: tHISindx(Ngrids)     ! history time record index
        integer  :: tHSSindx(Ngrids)     ! Hessian time record index
        integer  :: tINIindx(Ngrids)     ! initial NLM time record index
        integer  :: tIRPindx(Ngrids)     ! initial RPM time record index
        integer  :: tITLindx(Ngrids)     ! initial TLM time record index
        integer  :: tLCZindx(Ngrids)     ! Lanczos time record index
        integer  :: tNRMindx(4,Ngrids)   ! norm time record index
        integer  :: tRSTindx(Ngrids)     ! restart time record index
        integer  :: tSTAindx(Ngrids)     ! stations time record index
        integer  :: tTLFindx(Ngrids)     ! TLM impulse time record index
        integer  :: tTLMindx(Ngrids)     ! tangent time record index
!
!  Input/Output information variables.
!
        logical  :: Linfo(4,NV,Ngrids)
        integer  :: Iinfo(9,NV,Ngrids)
        real(r8) :: Finfo(9,NV,Ngrids)
        real(r8) :: Fpoint(2,NV,Ngrids)
        real(r8) :: Fscale(NV,Ngrids)
        real(r8) :: Tintrp(2,NV,Ngrids)
        real(r8), allocatable :: Vtime(:,:,:)
        character (len=5  ) :: version = '3.2  '
        character (len=40 ) :: varnam(MV)
        character (len=44 ) :: date_str
        character (len=46 ) :: Tname(0:NV)
        character (len=80 ) :: Cinfo(NV,Ngrids)
        character (len=100) :: Vname(5,0:NV)
        character (len=120) :: history
!
!  Source code root directory, cpp header file and directory, and
!  analytical expression directory.
!
        character (len=80 ) :: Rdir
        character (len=80 ) :: Hdir
        character (len=80 ) :: Hfile
        character (len=80)  :: Adir
!
!  Analyical header file logical and names.
!
        logical :: Lanafile
        character (len=200), dimension(37) :: ANANAME
!
!  Biology models file logical and names.
!
        logical, dimension(4) :: Lbiofile
        character (len=200), dimension(4) :: BIONAME
!
!  SVN revision and repository root URL.
!
        character (len=40 ) :: svn_rev
        character (len=120) :: svn_url
      CONTAINS
      SUBROUTINE initialize_ncparam
!
!=======================================================================
!                                                                      !
!  This routine allocates and initializes all variables in module      !
!  "mod_ncparam" for all nested grids.                                 !
!                                                                      !
!=======================================================================
!
        USE mod_parallel
        USE mod_iounits
        USE mod_scalars
!
!  Local variable declarations.
!
        logical :: load
        integer, parameter :: inp = 10
        integer :: Itile, Jtile
        integer :: Lvar, Ntiles, i, ic, ie, is, j, ng
        integer :: gtype, tile, varid
        real(r8), parameter :: epsilon = 1.0E-8_r8 
        real(r8), parameter :: spv = 0.0_r8 
        real(r8) :: offset, scale
        character (len=80), dimension(7) :: Vinfo
!
!-----------------------------------------------------------------------
!  Allocate several indices variables.
!-----------------------------------------------------------------------
!
        allocate ( idRtrc(MT) )
        allocate ( idTbot(MT) )
        allocate ( idTads(MT) )
        allocate ( idTbry(4,MT) )
        allocate ( idTclm(MT) )
        allocate ( idTerr(MT) )
        allocate ( idTobs(MT) )
        allocate ( idTsur(MT) )
        allocate ( idTtlf(MT) )
        allocate ( idTvar(MT) )
        allocate ( isTvar(MT) )
        allocate ( isTsur(MT) )
        allocate ( adjTid(MT,Ngrids) )
        allocate ( avgTid(MT,Ngrids) )
        allocate ( fltTid(MT,Ngrids) )
        allocate ( errTid(MT,Ngrids) )
        allocate ( hisTid(MT,Ngrids) )
        allocate ( hssTid(MT,Ngrids) )
        allocate ( iniTid(MT,Ngrids) )
        allocate ( irpTid(MT,Ngrids) )
        allocate ( itlTid(MT,Ngrids) )
        allocate ( lczTid(MT,Ngrids) )
        allocate ( obsTid(MT,Ngrids) )
        allocate ( rstTid(MT,Ngrids) )
        allocate ( staTid(MT,Ngrids) )
        allocate ( tlfTid(MT,Ngrids) )
        allocate ( tlmTid(MT,Ngrids) )
        allocate ( iHUTav(NAT) )
        allocate ( iHVTav(NAT) )
        allocate ( idTTav(NAT) )
        allocate ( idUTav(NAT) )
        allocate ( idVTav(NAT) )
        allocate ( idDar1d(NBP1) )
        allocate ( idDar2d(NBP2) )
        allocate ( iPgrowth(npmax) ) ! Phytoplankton growth (in PO4)
        allocate ( iPgraz(npmax) )    ! Phytoplankton loss due to grazing
        allocate ( iPmort(npmax) )    ! Phytoplankton loss due to mortality
        allocate ( iPsink(npmax) ) ! Phytoplankton sinking flux divergence
        allocate ( iZgrazP(nzmax)  ) ! Zooplankton Phosphorous gain due to grazing
        allocate ( iZgrazN(nzmax)  ) ! Zooplankton Nitrogen gain due to grazing
        allocate ( iZgrazSi(nzmax) ) ! Zooplankton Silica gain due to grazing
        allocate ( iZmortP(nzmax) )   ! Zooplankton Phosphorous loss due to mortality
        allocate ( iZmortN(nzmax) )   ! Zooplankton Nitrogen loss due to mortality
        allocate ( iZmortSi(nzmax) )  ! Zooplankton Silica loss due to mortality
        allocate ( ilimI(npmax) ) ! light limitation factor
        allocate ( ilimN(npmax) ) ! nitrogen limitation factor
        allocate ( ilimP(npmax) ) ! iron limitation factor
        allocate ( ilimSi(npmax) ) ! silica limitation factor
        allocate ( ilimT(npmax) ) ! temp limitation factor
        allocate ( ilimCTRL(npmax) ) ! control_nut factor when nut are too low
        allocate ( iDbio2(NDbio2d) )
        allocate ( iDbio3(NDbio3d) )
        allocate ( idDtrc(MT,NDT) )
        allocate ( idDu2d(NDM2d) )
        allocate ( idDv2d(NDM2d) )
        allocate ( idDu3d(NDM3d) )
        allocate ( idDv3d(NDM3d) )
        allocate ( idSvar(MAXVAL(NSV)+1) )
        allocate ( idSbry(MAXVAL(NSV)+1) )
        allocate ( Vtime(2,NV,Ngrids) )
!
!-----------------------------------------------------------------------
!  Set minimum and maximum fractional coordinates for processing
!  observations. Either the full grid or only interior points will
!  be considered.  The strategy here is to add a small value (epsilon)
!  to the eastern and northern boundary values of Xmax and Ymax so
!  observations at such boundaries locations are processed. This
!  is needed because the .lt. operator in the following conditional:
!
!     IF (...
!    &    ((Xmin.le.Xobs(iobs)).and.(Xobs(iobs).lt.Xmax)).and.          &
!    &    ((Ymin.le.Yobs(iobs)).and.(Yobs(iobs).lt.Ymax))) THEN
!-----------------------------------------------------------------------
!   
!  Allocate fractional grid lower and upper bounds structure.
!
      IF (.not.allocated(DOMAIN)) THEN
        allocate ( DOMAIN(Ngrids) )
        DO ng=1,Ngrids
          Ntiles=NtileI(ng)*NtileJ(ng)-1
          allocate ( DOMAIN(ng) % Xmin_psi (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmax_psi (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymin_psi (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymax_psi (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmin_rho (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmax_rho (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymin_rho (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymax_rho (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmin_u   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmax_u   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymin_u   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymax_u   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmin_v   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Xmax_v   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymin_v   (0:Ntiles) )
          allocate ( DOMAIN(ng) % Ymax_v   (0:Ntiles) )
        END DO
      END IF
!
!  Initialize.
!
      DO ng=1,Ngrids
        DOMAIN(ng) % Xmin_psi = spv
        DOMAIN(ng) % Xmax_psi = spv
        DOMAIN(ng) % Ymin_psi = spv
        DOMAIN(ng) % Ymax_psi = spv
        DOMAIN(ng) % Xmin_rho = spv
        DOMAIN(ng) % Xmax_rho = spv
        DOMAIN(ng) % Ymin_rho = spv
        DOMAIN(ng) % Ymax_rho = spv
        DOMAIN(ng) % Xmin_u   = spv
        DOMAIN(ng) % Xmax_u   = spv
        DOMAIN(ng) % Ymin_u   = spv
        DOMAIN(ng) % Ymax_u   = spv
        DOMAIN(ng) % Xmin_v   = spv
        DOMAIN(ng) % Xmax_v   = spv
        DOMAIN(ng) % Ymin_v   = spv
        DOMAIN(ng) % Ymax_v   = spv
      END DO
!
!  Set RHO-points domain lower and upper bounds (integer).
!
      DO ng=1,Ngrids
        CALL get_bounds (ng, MyRank, r2dvar, 0, Itile, Jtile,           &
     &                   rILB(ng), rIUB(ng), rJLB(ng), rJUB(ng))
        IF (Itile.eq.0) THEN
          rILB(ng)=rILB(ng)+1
        END IF
        IF (Itile.eq.(NtileI(ng)-1)) THEN
          rIUB(ng)=rIUB(ng)-1
        END IF
        IF (Jtile.eq.0) THEN
          rJLB(ng)=rJLB(ng)+1
        END IF
        IF (Jtile.eq.(NtileJ(ng)-1)) THEN
          rJUB(ng)=rJUB(ng)-1
        END IF
!
!  Minimum and maximum fractional coordinates for RHO-points.
!
        DO tile=0,NtileI(ng)*NtileJ(ng)-1
          CALL get_domain (ng, tile, r2dvar, 0, epsilon,                &
     &                     .FALSE.,                                     &
     &                     DOMAIN(ng) % Xmin_rho(tile),                 &
     &                     DOMAIN(ng) % Xmax_rho(tile),                 &
     &                     DOMAIN(ng) % Ymin_rho(tile),                 &
     &                     DOMAIN(ng) % Ymax_rho(tile))
        END DO
        rXmin(ng)=DOMAIN(ng)%Xmin_rho(MyRank)
        rXmax(ng)=DOMAIN(ng)%Xmax_rho(MyRank)
        rYmin(ng)=DOMAIN(ng)%Ymin_rho(MyRank)
        rYmax(ng)=DOMAIN(ng)%Ymax_rho(MyRank)
      END DO
!
!  Set U-points domain lower and upper bounds (integer).
!
      DO ng=1,Ngrids
        CALL get_bounds (ng, MyRank, u2dvar, 0, Itile, Jtile,           &
     &                   uILB(ng), uIUB(ng), uJLB(ng), uJUB(ng))
        IF (Itile.eq.0) THEN
          uILB(ng)=uILB(ng)+1
        END IF
        IF (Itile.eq.(NtileI(ng)-1)) THEN
          uIUB(ng)=uIUB(ng)-1
        END IF
        IF (Jtile.eq.0) THEN
          uJLB(ng)=uJLB(ng)+1
        END IF
        IF (Jtile.eq.(NtileJ(ng)-1)) THEN
          uJUB(ng)=uJUB(ng)-1
        END IF
!
!  Minimum and maximum fractional coordinates for U-points.
!
        DO tile=0,NtileI(ng)*NtileJ(ng)-1
          CALL get_domain (ng, tile, u2dvar, 0, epsilon,                &
     &                     .FALSE.,                                     &
     &                     DOMAIN(ng) % Xmin_u(tile),                   &
     &                     DOMAIN(ng) % Xmax_u(tile),                   &
     &                     DOMAIN(ng) % Ymin_u(tile),                   &
     &                     DOMAIN(ng) % Ymax_u(tile))
        END DO
        uXmin(ng)=DOMAIN(ng)%Xmin_u(MyRank)
        uXmax(ng)=DOMAIN(ng)%Xmax_u(MyRank)
        uYmin(ng)=DOMAIN(ng)%Ymin_u(MyRank)
        uYmax(ng)=DOMAIN(ng)%Ymax_u(MyRank)
      END DO
!
!  Set V-points domain lower and upper bounds (integer).
!
      DO ng=1,Ngrids
        CALL get_bounds (ng, MyRank, v2dvar, 0, Itile, Jtile,           &
     &                   vILB(ng), vIUB(ng), vJLB(ng), vJUB(ng))
        IF (Itile.eq.0) THEN
          vILB(ng)=vILB(ng)+1
        END IF
        IF (Itile.eq.(NtileI(ng)-1)) THEN
          vIUB(ng)=vIUB(ng)-1
        END IF
        IF (Jtile.eq.0) THEN
          vJLB(ng)=vJLB(ng)+1
        END IF
        IF (Jtile.eq.(NtileJ(ng)-1)) THEN
          vJUB(ng)=vJUB(ng)-1
        END IF
!
!  Minimum and maximum fractional coordinates for V-points.
!
        DO tile=0,NtileI(ng)*NtileJ(ng)-1
          CALL get_domain (ng, tile, v2dvar, 0, epsilon,                &
     &                     .FALSE.,                                     &
     &                     DOMAIN(ng) % Xmin_v(tile),                   &
     &                     DOMAIN(ng) % Xmax_v(tile),                   &
     &                     DOMAIN(ng) % Ymin_v(tile),                   &
     &                     DOMAIN(ng) % Ymax_v(tile))
        END DO
        vXmin(ng)=DOMAIN(ng)%Xmin_v(MyRank)
        vXmax(ng)=DOMAIN(ng)%Xmax_v(MyRank)
        vYmin(ng)=DOMAIN(ng)%Ymin_v(MyRank)
        vYmax(ng)=DOMAIN(ng)%Ymax_v(MyRank)
      END DO
!
!-----------------------------------------------------------------------
!  Initialize several variables.
!-----------------------------------------------------------------------
!
!  Initialize NetCDF files IDs to closed state.
!
        DO ng=1,Ngrids
          DO i=1,NV
            ncFRCid(i,ng)=-1
          END DO
          ncADJid(ng)=-1
          ncADSid(ng)=-1
          ncAVGid(ng)=-1
          ncBRYid(ng)=-1
          ncCLMid(ng)=-1
          ncDIAid(ng)=-1
          ncERRid(ng)=-1
          ncFLTid(ng)=-1
          ncGSTid(ng)=-1
          ncFWDid(ng)=-1
          ncGRDid(ng)=-1
          ncHISid(ng)=-1
          ncHSSid(ng)=-1
          ncINIid(ng)=-1
          ncIRPid(ng)=-1
          ncITLid(ng)=-1
          ncLCZid(ng)=-1
          ncMODid(ng)=-1
          ncNRMid(1:4,ng)=-1
          ncOBSid(ng)=-1
          ncRSTid(ng)=-1
          ncSSHid(ng)=-1
          ncSSTid(ng)=-1
          ncSTAid(ng)=-1
          ncTIDEid(ng)=-1
          ncTLFid(ng)=-1
          ncTLMid(ng)=-1
          ncTOBSid(ng)=-1
          ncVOBSid(ng)=-1
          ncVSURid(ng)=-1
          tADJindx(ng)=0
          tAVGindx(ng)=0
          tDIAindx(ng)=0
          tFLTindx(ng)=0
          tHISindx(ng)=0
          tINIindx(ng)=0
          tIRPindx(ng)=1
          tITLindx(ng)=1
          tNRMindx(1:4,ng)=0
          tRSTindx(ng)=0
          tSTAindx(ng)=0
          tTLFindx(ng)=0
          tTLMindx(ng)=0
          idefADJ(ng)=-1
          idefAVG(ng)=-1
          idefDIA(ng)=-1
          idefHIS(ng)=-1
          idefTLM(ng)=-1
        END DO
!
!  Analytical files switch and names.
!
        Lanafile=.TRUE.
        DO i=1,37
          DO j=1,200
            ANANAME(i)(j:j)=' '
          END DO
        END DO
!
!  Biology model header names.
!
        DO i=1,4
          Lbiofile(i)=.TRUE.
          DO j=1,200
            BIONAME(i)(j:j)=' '
          END DO
        END DO
!
!  Set IDs for state some state variables. 
!
        ic=5
        DO i=1,MT
          ic=ic+1
          isTvar(i)=ic
        END DO
!
!  Initialize biology diagnostic indices.
!
        icae=0
        iloc=1
        DO i=1,npmax
          iPgrowth(i)=icae+iloc
          iloc=iloc+1
          iPgraz(i)=icae+iloc
          iloc=iloc+1
          iPmort(i)=icae+iloc
          iloc=iloc+1
          iPsink(i)=icae+iloc
          iloc=iloc+1
          ilimI(i)=icae+iloc
          iloc=iloc+1
          ilimN(i)=icae+iloc
          iloc=iloc+1
          ilimP(i)=icae+iloc
          iloc=iloc+1
          ilimSi(i)=icae+iloc
          iloc=iloc+1
          ilimT(i)=icae+iloc
          iloc=iloc+1
          ilimCTRL(i)=icae+iloc
          iloc=iloc+1
        END DO
        DO i=1,nzmax
          iZgrazP(i)=icae+iloc
          iloc=iloc+1
          iZgrazN(i)=icae+iloc
          iloc=iloc+1
          iZgrazSi(i)=icae+iloc
          iloc=iloc+1
          iZmortP(i)=icae+iloc
          iloc=iloc+1
          iZmortN(i)=icae+iloc
          iloc=iloc+1
          iZmortSi(i)=icae+iloc
          iloc=iloc+1
        END DO
        iNO3prod=icae+iloc
        iloc=iloc+1
        iNO2prod=icae+iloc
        iloc=iloc+1
        iuptakePO4=icae+iloc
        iloc=iloc+1
        iuptakeNH4=icae+iloc
        iloc=iloc+1
        iuptakeNO2=icae+iloc
        iloc=iloc+1
        iuptakeNO3=icae+iloc
        iloc=iloc+1
        iuptakeSi=icae+iloc
        iloc=iloc+1
        iPOPgraz=icae+iloc
        iloc=iloc+1
        iPONgraz=icae+iloc
        iloc=iloc+1
        iPSigraz=icae+iloc
        iloc=iloc+1
        iDOPgraz=icae+iloc
        iloc=iloc+1
        iDONgraz=icae+iloc
        iloc=iloc+1
        iPOPexportP=icae+iloc
        iloc=iloc+1
        iPONexportP=icae+iloc
        iloc=iloc+1
        iPSiexportP=icae+iloc
        iloc=iloc+1
        iDOPexportP=icae+iloc
        iloc=iloc+1
        iDONexportP=icae+iloc
        iloc=iloc+1
        iPOPexportZ=icae+iloc
        iloc=iloc+1
        iPONexportZ=icae+iloc
        iloc=iloc+1
        iPSiexportZ=icae+iloc
        iloc=iloc+1
        iDOPexportZ=icae+iloc
        iloc=iloc+1
        iDONexportZ=icae+iloc
        iloc=iloc+1
        isinkPOP=icae+iloc
        iloc=iloc+1
        isinkPON=icae+iloc
        iloc=iloc+1
        isinkPSi=icae+iloc
        iloc=iloc+1
        iPOPremin=icae+iloc
        iloc=iloc+1
        iPONremin=icae+iloc
        iloc=iloc+1
        iPSiremin=icae+iloc
        iloc=iloc+1
        iDOPremin=icae+iloc
        iloc=iloc+1
        iDONremin=icae+iloc
        iloc=iloc+1
        iPProd=icae+iloc
        iloc=iloc+1
!
!  Initialize IO information variables.
!
        DO ng=1,Ngrids
          DO i=1,NV
            Linfo(1,i,ng)=.FALSE.
            Linfo(2,i,ng)=.FALSE.
            Linfo(3,i,ng)=.FALSE.
            Linfo(4,i,ng)=.FALSE.
            Hout(i,ng)=.FALSE.
            Sout(i,ng)=.FALSE.
            Iinfo(1,i,ng)=0
            Iinfo(2,i,ng)=-1
            Iinfo(3,i,ng)=-1
            Iinfo(4,i,ng)=0
            Iinfo(5,i,ng)=0
            Iinfo(6,i,ng)=0
            Iinfo(7,i,ng)=0
            Iinfo(8,i,ng)=0
            Iinfo(9,i,ng)=0
            Finfo(1,i,ng)=0.0_r8
            Finfo(2,i,ng)=0.0_r8
            Finfo(3,i,ng)=0.0_r8
            Finfo(5,i,ng)=0.0_r8
            Finfo(6,i,ng)=0.0_r8
            Finfo(7,i,ng)=0.0_r8
            Fscale(i,ng)=1.0_r8
            Fpoint(1,i,ng)=0.0_r8
            Fpoint(2,i,ng)=0.0_r8
            Tintrp(1,i,ng)=0.0_r8
            Tintrp(2,i,ng)=0.0_r8
            Vtime(1,i,ng)=0.0_r8
            Vtime(2,i,ng)=0.0_r8
          END DO
        END DO
!
!  Set source code root directory, cpp header file and directory, and
!  analytical expression directory.
!
        Rdir="/net/head/export/254/ngoebel/darwin/darwin_20110408/roms-code"
        Hdir="/home/ngoebel/darwin/darwin_20110408/Include"
        Hfile="uswc_darwin.h"
        Adir="/home/ngoebel/darwin/darwin_20110408/Functionals"
!
!-----------------------------------------------------------------------
!  Define names of variables for Input/Output NetCDF files.
!-----------------------------------------------------------------------
!
!  Open input variable information file.
!
        OPEN (inp, FILE=TRIM(varname), FORM='formatted', STATUS='old',  &
     &        ERR=10)
        GOTO 20
  10    IF (Master) WRITE(stdout,50) TRIM(varname)
        STOP
  20    CONTINUE
!
!  Read in variable information.  Ignore blank and comment [char(33)=!]
!  input lines.
!
        varid=0
        DO WHILE (.TRUE.)
          READ (inp,*,ERR=30,END=40) Vinfo(1)
          Lvar=LEN_TRIM(Vinfo(1))
!
!  Extract SVN Repository Root URL.
!            
          IF ((Lvar.gt.0).and.(Vinfo(1)(1:1).eq.CHAR(36))) THEN
            is=INDEX(Vinfo(1),'https')
            ie=INDEX(Vinfo(1),'/ROMS')-1
            svn_url=Vinfo(1)(is:ie)
            svn_rev="382M"
!
!  Read in other variable information.
!
          ELSE IF ((Lvar.gt.0).and.(Vinfo(1)(1:1).ne.CHAR(33))) THEN
            READ (inp,*,ERR=30) Vinfo(2)
            READ (inp,*,ERR=30) Vinfo(3)
            READ (inp,*,ERR=30) Vinfo(4)
            READ (inp,*,ERR=30) Vinfo(5)
            READ (inp,*,ERR=30) Vinfo(6)
            READ (inp,*,ERR=30) Vinfo(7)
            READ (inp,*,ERR=30) scale
!
!  Determine staggered C-grid variable.
!
            SELECT CASE (TRIM(ADJUSTL(Vinfo(7))))
              CASE ('p2dvar')
                gtype=p2dvar
              CASE ('r2dvar')
                gtype=r2dvar
              CASE ('u2dvar')
                gtype=u2dvar
              CASE ('v2dvar')
                gtype=v2dvar
              CASE ('p3dvar')
                gtype=p3dvar
              CASE ('r3dvar')
                gtype=r3dvar
              CASE ('u3dvar')
                gtype=u3dvar
              CASE ('v3dvar')
                gtype=v3dvar
              CASE ('w3dvar')
                gtype=w3dvar
              CASE ('b3dvar')
                gtype=b3dvar
              CASE DEFAULT
                gtype=0
            END SELECT
!
!  Assign identification indices.
!
            load=.TRUE.
            varid=varid+1
            SELECT CASE (TRIM(ADJUSTL(Vinfo(6))))
              CASE ('idtime')
                idtime=varid
              CASE ('idbath')
                idbath=varid
              CASE ('idFsur')
                idFsur=varid
              CASE ('idRzet')
                idRzet=varid
              CASE ('idUbar')
                idUbar=varid
              CASE ('idRu2d')
                idRu2d=varid
              CASE ('idVbar')
                idVbar=varid
              CASE ('idRv2d')
                idRv2d=varid
              CASE ('idUvel')
                idUvel=varid
              CASE ('idRu3d')
                idRu3d=varid
              CASE ('idVvel')
                idVvel=varid
              CASE ('idRv3d')
                idRv3d=varid
              CASE ('idWvel')
                idWvel=varid
              CASE ('idOvel')
                idOvel=varid
              CASE ('idDano')
                idDano=varid
              CASE ('idTvar(itemp)')
                idTvar(itemp)=varid
              CASE ('idTvar(isalt)')
                idTvar(isalt)=varid
              CASE ('idUsms')
                idUsms=varid
              CASE ('idVsms')
                idVsms=varid
              CASE ('idUbms')
                idUbms=varid
              CASE ('idVbms')
                idVbms=varid
              CASE ('idUbws')
                idUbws=varid
              CASE ('idUbcs')
                idUbcs=varid
              CASE ('idVbws')
                idVbws=varid
              CASE ('idVbcs')
                idVbcs=varid
              CASE ('idTsur(itemp)')
                idTsur(itemp)=varid
              CASE ('iddQdT')
                iddQdT=varid
              CASE ('idsfwf')
                idsfwf=varid
              CASE ('idTsur(isalt)')
                idTsur(isalt)=varid
              CASE ('idTbot(itemp)')
                idTbot(itemp)=varid
              CASE ('idTbot(isalt)')
                idTbot(isalt)=varid
              CASE ('idGhat(itemp)')
                idGhat(itemp)=varid
              CASE ('idGhat(isalt)')
                idGhat(isalt)=varid
              CASE ('idMtke')
                idMtke=varid
              CASE ('idMtls')
                idMtls=varid
              CASE ('idVvis')
                idVvis=varid
              CASE ('idTdif')
                idTdif=varid
                idDiff(itemp)=idTdif 
              CASE ('idSdif')
                idSdif=varid
                idDiff(isalt)=idSdif 
              CASE ('idVmLS')
                idVmLS=varid
              CASE ('idVmKK')
                idVmKK=varid
              CASE ('idVmKP')
                idVmKP=varid
              CASE ('idZbry(iwest)')
                idZbry(iwest)=varid
              CASE ('idZbry(ieast)')
                idZbry(ieast)=varid
              CASE ('idZbry(isouth)')
                idZbry(isouth)=varid
              CASE ('idZbry(inorth)')
                idZbry(inorth)=varid
              CASE ('idU2bc(iwest)')
                idU2bc(iwest)=varid
              CASE ('idU2bc(ieast)')
                idU2bc(ieast)=varid
              CASE ('idU2bc(isouth)')
                idU2bc(isouth)=varid
              CASE ('idU2bc(inorth)')
                idU2bc(inorth)=varid
              CASE ('idV2bc(iwest)')
                idV2bc(iwest)=varid
              CASE ('idV2bc(ieast)')
                idV2bc(ieast)=varid
              CASE ('idV2bc(isouth)')
                idV2bc(isouth)=varid
              CASE ('idV2bc(inorth)')
                idV2bc(inorth)=varid
              CASE ('idU3bc(iwest)')
                idU3bc(iwest)=varid
              CASE ('idU3bc(ieast)')
                idU3bc(ieast)=varid
              CASE ('idU3bc(isouth)')
                idU3bc(isouth)=varid
              CASE ('idU3bc(inorth)')
                idU3bc(inorth)=varid
              CASE ('idV3bc(iwest)')
                idV3bc(iwest)=varid
              CASE ('idV3bc(ieast)')
                idV3bc(ieast)=varid
              CASE ('idV3bc(isouth)')
                idV3bc(isouth)=varid
              CASE ('idV3bc(inorth)')
                idV3bc(inorth)=varid
              CASE ('idTbry(iwest,itemp)')
                idTbry(iwest,itemp)=varid
              CASE ('idTbry(ieast,itemp)')
                idTbry(ieast,itemp)=varid
              CASE ('idTbry(isouth,itemp)')
                idTbry(isouth,itemp)=varid
              CASE ('idTbry(inorth,itemp)')
                idTbry(inorth,itemp)=varid
              CASE ('idTbry(iwest,isalt)')
                idTbry(iwest,isalt)=varid
              CASE ('idTbry(ieast,isalt)')
                idTbry(ieast,isalt)=varid
              CASE ('idTbry(isouth,isalt)')
                idTbry(isouth,isalt)=varid
              CASE ('idTbry(inorth,isalt)')
                idTbry(inorth,isalt)=varid
              CASE ('idRwet')
                idRwet=varid
              CASE ('idUwet')
                idUwet=varid
              CASE ('idVwet')
                idVwet=varid
              CASE ('idPair')
                idPair=varid
              CASE ('idTair')
                idTair=varid
              CASE ('idQair')
                idQair=varid
              CASE ('idCfra')
                idCfra=varid
              CASE ('idSrad')
                idSrad=varid
              CASE ('idLdwn')
                idLdwn=varid
              CASE ('idLrad')
                idLrad=varid
              CASE ('idLhea')
                idLhea=varid
              CASE ('idShea')
                idShea=varid
              CASE ('idrain')
                idrain=varid
              CASE ('idevap')
                idevap=varid
              CASE ('idUair')
                idUair=varid
              CASE ('idVair')
                idVair=varid
              CASE ('idWamp')
                idWamp=varid
              CASE ('idWbrk')
                idWbrk=varid
              CASE ('idWdis')
                idWdis=varid
              CASE ('idWdir')
                idWdir=varid
              CASE ('idWlen')
                idWlen=varid
              CASE ('idWptp')
                idWptp=varid
              CASE ('idWpbt')
                idWpbt=varid
              CASE ('idWorb')
                idWorb=varid
              CASE ('idW2xx')
                idW2xx=varid
              CASE ('idW2xy')
                idW2xy=varid
              CASE ('idW2yy')
                idW2yy=varid
              CASE ('idW3xx')
                idW3xx=varid
              CASE ('idW3xy')
                idW3xy=varid
              CASE ('idW3yy')
                idW3yy=varid
              CASE ('idW3zx')
                idW3zx=varid
              CASE ('idW3zy')
                idW3zy=varid
              CASE ('idU2rs')
                idU2rs=varid
              CASE ('idV2rs')
                idV2rs=varid
              CASE ('idU2Sd')
                idU2Sd=varid
              CASE ('idV2Sd')
                idV2Sd=varid
              CASE ('idU3rs')
                idU3rs=varid
              CASE ('idV3rs')
                idV3rs=varid
              CASE ('idU3Sd')
                idU3Sd=varid
              CASE ('idV3Sd')
                idV3Sd=varid
              CASE ('idTper')
                idTper=varid
              CASE ('idTzam')
                idTzam=varid
              CASE ('idTzph')
                idTzph=varid
              CASE ('idTvph')
                idTvph=varid
              CASE ('idTvan')
                idTvan=varid
              CASE ('idTvma')
                idTvma=varid
              CASE ('idTvmi')
                idTvmi=varid
              CASE ('idRxpo')
                idRxpo=varid
              CASE ('idRepo')
                idRepo=varid
              CASE ('idRdir')
                idRdir=varid
              CASE ('idRvsh')
                idRvsh=varid
              CASE ('idRtra')
                idRtra=varid
              CASE ('idRflg')
                idRflg=varid
              CASE ('idRtrc(itemp)')
                idRtrc(itemp)=varid
              CASE ('idRtrc(isalt)')
                idRtrc(isalt)=varid
              CASE ('idHsbl')
                idHsbl=varid
              CASE ('idHbbl')
                idHbbl=varid
              CASE ('idUbot')
                idUbot=varid
              CASE ('idVbot')
                idVbot=varid
              CASE ('idUbur')
                idUbur=varid
              CASE ('idVbvr')
                idVbvr=varid
              CASE ('idUbrs')
                idUbrs=varid
              CASE ('idVbrs')
                idVbrs=varid
              CASE ('idSSHc')
                idSSHc=varid
              CASE ('idUbcl')
                idUbcl=varid
              CASE ('idVbcl')
                idVbcl=varid
              CASE ('idUclm')
                idUclm=varid
              CASE ('idVclm')
                idVclm=varid
              CASE ('idSSSc')
                idSSSc=varid
              CASE ('idSSTc')
                idSSTc=varid
              CASE ('idTclm(itemp)')
                idTclm(itemp)=varid
              CASE ('idTclm(isalt)')
                idTclm(isalt)=varid
              CASE ('idSSHo')
                idSSHo=varid
              CASE ('idSSHe')
                idSSHe=varid
              CASE ('idUobs')
                idUobs=varid
              CASE ('idVobs')
                idVobs=varid
              CASE ('idUVer')
                idUVer=varid
              CASE ('idUsur')
                idUsur=varid
              CASE ('idVsur')
                idVsur=varid
              CASE ('idUVse')
                idUVse=varid
              CASE ('idSSTo')
                idSSTo=varid
              CASE ('idSSTe')
                idSSTe=varid
              CASE ('idTobs(itemp)')
                idTobs(itemp)=varid
              CASE ('idTerr(itemp)')
                idTerr(itemp)=varid
              CASE ('idTobs(isalt)')
                idTobs(isalt)=varid
              CASE ('idTerr(isalt)')
                idTerr(isalt)=varid
              CASE ('idTvar(iPhyt)')
                load=.TRUE.
              CASE ('idTvar(iZooP)')
                load=.TRUE.
              CASE ('idTvar(iZooN)')
                load=.TRUE.
              CASE ('idTvar(iZooFe)')
                load=.TRUE.
              CASE ('idTvar(iZooSi)')
                load=.TRUE.
              CASE ('idTvar(iNO3)')
                idTvar(iNO3)=varid
              CASE ('idTvar(iNO2)')
                idTvar(iNO2)=varid
              CASE ('idTvar(iFeT)')
                idTvar(iFeT)=varid
              CASE ('idTvar(iSi)')
                idTvar(iSi)=varid
              CASE ('idTvar(iNH4)')
                idTvar(iNH4)=varid
              CASE ('idTvar(iPO4)')
                idTvar(iPO4)=varid
              CASE ('idTvar(iDOP)')
                idTvar(iDOP)=varid
              CASE ('idTvar(iDON)')
                idTvar(iDON)=varid
              CASE ('idTvar(iDOFe)')
                idTvar(iDOFe)=varid
              CASE ('idTvar(iPOP)')
                idTvar(iPOP)=varid
              CASE ('idTvar(iPON)')
                idTvar(iPON)=varid
              CASE ('idTvar(iPOFe)')
                idTvar(iPOFe)=varid
              CASE ('idTvar(iPSi)')
                idTvar(iPSi)=varid
              CASE ('idTbry(inorth,iPhyt)')
                load=.TRUE.
              CASE ('idTbry(inorth,iZooP)')
                load=.TRUE.
              CASE ('idTbry(inorth,iZooN)')
                load=.TRUE.
              CASE ('idTbry(inorth,iZooFe)')
                load=.TRUE.
              CASE ('idTbry(inorth,iZooSi)')
                load=.TRUE.
              CASE ('idTbry(inorth,iNO3)')
                idTbry(inorth,iNO3)=varid
              CASE ('idTbry(inorth,iNO2)')
                idTbry(inorth,iNO2)=varid
              CASE ('idTbry(inorth,iFeT)')
                idTbry(inorth,iFeT)=varid
              CASE ('idTbry(inorth,iSi)')
                idTbry(inorth,iSi)=varid
              CASE ('idTbry(inorth,iNH4)')
                idTbry(inorth,iNH4)=varid
              CASE ('idTbry(inorth,iPO4)')
                idTbry(inorth,iPO4)=varid
              CASE ('idTbry(inorth,iDOP)')
                idTbry(inorth,iDOP)=varid
              CASE ('idTbry(inorth,iDON)')
                idTbry(inorth,iDON)=varid
              CASE ('idTbry(inorth,iDOFe)')
                idTbry(inorth,iDOFe)=varid
              CASE ('idTbry(inorth,iPOP)')
                idTbry(inorth,iPOP)=varid
              CASE ('idTbry(inorth,iPON)')
                idTbry(inorth,iPON)=varid
              CASE ('idTbry(inorth,iPOFe)')
                idTbry(inorth,iPOFe)=varid
              CASE ('idTbry(inorth,iPSi)')
                idTbry(inorth,iPSi)=varid
              CASE ('idTbry(isouth,iPhyt)')
                load=.TRUE.
              CASE ('idTbry(isouth,iZooP)')
                load=.TRUE.
              CASE ('idTbry(isouth,iZooN)')
                load=.TRUE.
              CASE ('idTbry(isouth,iZooFe)')
                load=.TRUE.
              CASE ('idTbry(isouth,iZooSi)')
                load=.TRUE.
              CASE ('idTbry(isouth,iNO3)')
                idTbry(isouth,iNO3)=varid
              CASE ('idTbry(isouth,iNO2)')
                idTbry(isouth,iNO2)=varid
              CASE ('idTbry(isouth,iFeT)')
                idTbry(isouth,iFeT)=varid
              CASE ('idTbry(isouth,iSi)')
                idTbry(isouth,iSi)=varid
              CASE ('idTbry(isouth,iNH4)')
                idTbry(isouth,iNH4)=varid
              CASE ('idTbry(isouth,iPO4)')
                idTbry(isouth,iPO4)=varid
              CASE ('idTbry(isouth,iDOP)')
                idTbry(isouth,iDOP)=varid
              CASE ('idTbry(isouth,iDON)')
                idTbry(isouth,iDON)=varid
              CASE ('idTbry(isouth,iDOFe)')
                idTbry(isouth,iDOFe)=varid
              CASE ('idTbry(isouth,iPOP)')
                idTbry(isouth,iPOP)=varid
              CASE ('idTbry(isouth,iPON)')
                idTbry(isouth,iPON)=varid
              CASE ('idTbry(isouth,iPOFe)')
                idTbry(isouth,iPOFe)=varid
              CASE ('idTbry(isouth,iPSi)')
                idTbry(isouth,iPSi)=varid
              CASE ('idTbry(ieast,iPhyt)')
                load=.TRUE.
              CASE ('idTbry(ieast,iZooP)')
                load=.TRUE.
              CASE ('idTbry(ieast,iZooN)')
                load=.TRUE.
              CASE ('idTbry(ieast,iZooFe)')
                load=.TRUE.
              CASE ('idTbry(ieast,iZooSi)')
                load=.TRUE.
              CASE ('idTbry(ieast,iNO3)')
                idTbry(ieast,iNO3)=varid
              CASE ('idTbry(ieast,iNO2)')
                idTbry(ieast,iNO2)=varid
              CASE ('idTbry(ieast,iFeT)')
                idTbry(ieast,iFeT)=varid
              CASE ('idTbry(ieast,iSi)')
                idTbry(ieast,iSi)=varid
              CASE ('idTbry(ieast,iNH4)')
                idTbry(ieast,iNH4)=varid
              CASE ('idTbry(ieast,iPO4)')
                idTbry(ieast,iPO4)=varid
              CASE ('idTbry(ieast,iDOP)')
                idTbry(ieast,iDOP)=varid
              CASE ('idTbry(ieast,iDON)')
                idTbry(ieast,iDON)=varid
              CASE ('idTbry(ieast,iDOFe)')
                idTbry(ieast,iDOFe)=varid
              CASE ('idTbry(ieast,iPOP)')
                idTbry(ieast,iPOP)=varid
              CASE ('idTbry(ieast,iPON)')
                idTbry(ieast,iPON)=varid
              CASE ('idTbry(ieast,iPOFe)')
                idTbry(ieast,iPOFe)=varid
              CASE ('idTbry(ieast,iPSi)')
                idTbry(ieast,iPSi)=varid
              CASE ('idTbry(iwest,iPhyt)')
                load=.TRUE.
              CASE ('idTbry(iwest,iZooP)')
                load=.TRUE.
              CASE ('idTbry(iwest,iZooN)')
                load=.TRUE.
              CASE ('idTbry(iwest,iZooFe)')
                load=.TRUE.
              CASE ('idTbry(iwest,iZooSi)')
                load=.TRUE.
              CASE ('idTbry(iwest,iNO3)')
                idTbry(iwest,iNO3)=varid
              CASE ('idTbry(iwest,iNO2)')
                idTbry(iwest,iNO2)=varid
              CASE ('idTbry(iwest,iFeT)')
                idTbry(iwest,iFeT)=varid
              CASE ('idTbry(iwest,iSi)')
                idTbry(iwest,iSi)=varid
              CASE ('idTbry(iwest,iNH4)')
                idTbry(iwest,iNH4)=varid
              CASE ('idTbry(iwest,iPO4)')
                idTbry(iwest,iPO4)=varid
              CASE ('idTbry(iwest,iDOP)')
                idTbry(iwest,iDOP)=varid
              CASE ('idTbry(iwest,iDON)')
                idTbry(iwest,iDON)=varid
              CASE ('idTbry(iwest,iDOFe)')
                idTbry(iwest,iDOFe)=varid
              CASE ('idTbry(iwest,iPOP)')
                idTbry(iwest,iPOP)=varid
              CASE ('idTbry(iwest,iPON)')
                idTbry(iwest,iPON)=varid
              CASE ('idTbry(iwest,iPOFe)')
                idTbry(iwest,iPOFe)=varid
              CASE ('idTbry(iwest,iPSi)')
                idTbry(iwest,iPSi)=varid
              CASE ('iDbio3(ilimI)')
                load=.TRUE.
              CASE ('iDbio3(ilimN)')
                load=.TRUE.
              CASE ('iDbio3(ilimP)')
                load=.TRUE.
              CASE ('iDbio3(ilimSi)')
                load=.TRUE.
              CASE ('iDbio3(ilimT)')
                load=.TRUE.
              CASE ('iDbio3(ilimCTRL)')
                load=.TRUE.
              CASE ('iDbio3(iuptakePO4)')
                iDbio3(iuptakePO4)=varid
              CASE ('iDbio3(iuptakeNH4)')
                iDbio3(iuptakeNH4)=varid
              CASE ('iDbio3(iuptakeNO2)')
                iDbio3(iuptakeNO2)=varid
              CASE ('iDbio3(iuptakeNO3)')
                iDbio3(iuptakeNO3)=varid
              CASE ('iDbio3(iuptakeSi)')
                iDbio3(iuptakeSi)=varid
              CASE ('iDbio3(iNO3prod)')
                iDbio3(iNO3prod)=varid
              CASE ('iDbio3(iNO2prod)')
                iDbio3(iNO2prod)=varid
              CASE ('iDbio3(iPgrowth)')
                load=.TRUE.
              CASE ('iDbio3(iPgraz)')
                load=.TRUE.
              CASE ('iDbio3(iPmort)')
                load=.TRUE.
              CASE ('iDbio3(iPsink)')
                load=.TRUE.
              CASE ('iDbio3(iZgrazP)')
                load=.TRUE.
              CASE ('iDbio3(iZgrazN)')
                load=.TRUE.
              CASE ('iDbio3(iZgrazSi)')
                load=.TRUE.
              CASE ('iDbio3(iZmortP)')
                load=.TRUE.
              CASE ('iDbio3(iZmortN)')
                load=.TRUE.
              CASE ('iDbio3(iZmortSi)')
                load=.TRUE.
              CASE ('iDbio3(iPOPgraz)')
                iDbio3(iPOPgraz)=varid
              CASE ('iDbio3(iPONgraz)')
                iDbio3(iPONgraz)=varid
              CASE ('iDbio3(iPSigraz)')
                iDbio3(iPSigraz)=varid
              CASE ('iDbio3(iDOPgraz)')
                iDbio3(iDOPgraz)=varid
              CASE ('iDbio3(iDONgraz)')
                iDbio3(iDONgraz)=varid
              CASE ('iDbio3(iPOPexportP)')
                iDbio3(iPOPexportP)=varid
              CASE ('iDbio3(iPONexportP)')
                iDbio3(iPONexportP)=varid
              CASE ('iDbio3(iPSiexportP)')
                iDbio3(iPSiexportP)=varid
              CASE ('iDbio3(iDOPexportP)')
                iDbio3(iDOPexportP)=varid
              CASE ('iDbio3(iDONexportP)')
                iDbio3(iDONexportP)=varid
              CASE ('iDbio3(iPOPexportZ)')
                iDbio3(iPOPexportZ)=varid
              CASE ('iDbio3(iPONexportZ)')
                iDbio3(iPONexportZ)=varid
              CASE ('iDbio3(iPSiexportZ)')
                iDbio3(iPSiexportZ)=varid
              CASE ('iDbio3(iDOPexportZ)')
                iDbio3(iDOPexportZ)=varid
              CASE ('iDbio3(iDONexportZ)')
                iDbio3(iDONexportZ)=varid
              CASE ('iDbio3(isinkPOP)')
                iDbio3(isinkPOP)=varid
              CASE ('iDbio3(isinkPON)')
                iDbio3(isinkPON)=varid
              CASE ('iDbio3(isinkPSi)')
                iDbio3(isinkPSi)=varid
              CASE ('iDbio3(iPSiremin)')
                iDbio3(iPSiremin)=varid
              CASE ('iDbio3(iDOPremin)')
                iDbio3(iDOPremin)=varid
              CASE ('iDbio3(iDONremin)')
                iDbio3(iDONremin)=varid
              CASE ('iDbio3(iPOPremin)')
                iDbio3(iPOPremin)=varid
              CASE ('iDbio3(iPONremin)')
                iDbio3(iPONremin)=varid
              CASE ('iDbio3(iPProd)')
                iDbio3(iPProd)=varid
              CASE ('idDar1d(iSeedPP)')
                idDar1d(iSeedPP)=varid
              CASE ('idDar1d(iSeedPT)')
                idDar1d(iSeedPT)=varid
              CASE ('idDar2d(iSedPOP)')
                idDar2d(iSedPOP)=varid
              CASE ('idDar2d(iSedPON)')
                idDar2d(iSedPON)=varid
              CASE ('idDar2d(iSedPOFe)')
                idDar2d(iSedPOFe)=varid
              CASE ('idDar2d(iSedPOSi)')
                idDar2d(iSedPOSi)=varid
              CASE DEFAULT
                load=.FALSE.
            END SELECT
!
!  Load variable data into information arrays.
!
            IF (load) THEN
              load=.FALSE.
              IF (varid.gt.MV) THEN
                WRITE (stdout,60) MV, varid
                STOP
              END IF
              DO i=1,5
                Vname(i,varid)=TRIM(ADJUSTL(Vinfo(i)))
              END DO            
              DO ng=1,Ngrids
                Iinfo(1,varid,ng)=gtype
                Fscale(varid,ng)=scale
              END DO
              SELECT CASE (Vinfo(1))
                CASE ('Phyt')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    idTvar(iPhyt(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'Phyt_', i
                    WRITE (Vname(2,varid),'(a,i3.3,a)')                 &
     &                    'Phytoplankton ', i, ' concentration'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooP')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTvar(iZooP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2)') 'ZooP_', i
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i, ' P concentration'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooN')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTvar(iZooN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2)') 'ZooN_', i
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i, ' N concentration'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooFe')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTvar(iZooFe(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2)') 'ZooFe_', i
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i, ' Fe concentration'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooSi')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTvar(iZooSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2)') 'ZooSi_', i
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i, ' Si concentration'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Phyt_north')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    idTbry(inorth,iPhyt(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3,a)')                 &
     &                    'Phyt_', i,'_north'
                    WRITE (Vname(2,varid),'(a,i3.3,a)')                 &
     &                    'Phytoplankton ', i,                          &
     &                    ' northern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooP_north')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(inorth,iZooP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooP_', i,'_north'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' P concentration northern boundary condition'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooN_north')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(inorth,iZooN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooN_', i,'_north'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' N northern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooFe_north')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(inorth,iZooFe(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooFe_', i,'_north'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                   ' Fe northern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooSi_north')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(inorth,iZooSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooSi_', i,'_north'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                   ' Si northern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Phyt_south')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    idTbry(isouth,iPhyt(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3,a)')                 &
     &                    'Phyt_', i,'_south'
                    WRITE (Vname(2,varid),'(a,i3.3,a)')                 &
     &                    'Phytoplankton ', i,                          &
     &                    ' southern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooP_south')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(isouth,iZooP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooP_', i,'_south'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' P southern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooN_south')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(isouth,iZooN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooN_', i,'_south'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                   ' N southern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooFe_south')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(isouth,iZooFe(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooFe_', i,'_south'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                   ' Fe southern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooSi_south')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(isouth,iZooSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooSi_', i,'_south'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                   ' Si southern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Phyt_east')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    idTbry(ieast,iPhyt(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3,a)')                 &
     &                    'Phyt_', i,'_east'
                    WRITE (Vname(2,varid),'(a,i3.3,a)')                 &
     &                    'Phytoplankton ', i,                          &
     &                    ' eastern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooP_east')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(ieast,iZooP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooP_', i,'_east'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' P eastern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooN_east')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(ieast,iZooN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooN_', i,'_east'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' N eastern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooFe_east')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(ieast,iZooFe(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooFe_', i,'_east'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' Fe eastern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooSi_east')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(ieast,iZooSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooSi_', i,'_east'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' Si eastern bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Phyt_west')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    idTbry(iwest,iPhyt(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3,a)')                 &
     &                    'Phyt_', i,'_west'
                    WRITE (Vname(2,varid),'(a,i3.3,a)')                 &
     &                    'Phytoplankton ', i,                          &
     &                    ' western bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooP_west')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(iwest,iZooP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooP_', i,'_west'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' P western bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooN_west')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(iwest,iZooN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooN_', i,'_west'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' N western bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooFe_west')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(iwest,iZooFe(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooFe_', i,'_west'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' Fe western bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZooSi_west')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    idTbry(iwest,iZooSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i2.2,a)')                 &
     &                    'ZooSi_', i,'_west'
                    WRITE (Vname(2,varid),'(a,i2.2,a)')                 &
     &                    'Zooplankton ', i,                            &
     &                    ' Si western bc'
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
!
!  Adjust information for all Darwin diagnostics variables.
!
                CASE ('Pgrowth')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(iPgrowth(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'Pgrowth_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Growth, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Pgraz')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(iPgraz(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'Pgraz_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Grazing, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Pmort')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(iPmort(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'Pmort_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'mortality, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('Psink')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(iPsink(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'Psink_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'sinking, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZgrazP')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZgrazP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZgrazP_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Grazing (P), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZgrazN')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZgrazN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZgrazN_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Grazing (N), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZgrazSi')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZgrazSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZgrazSi_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Grazing (Si), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZmortP')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZmortP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZmortP_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Mortality (P), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZmortN')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZmortN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZmortN_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Mortality (N), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ZmortSi')
                  varid=varid-1
                  DO i=1,nzmax
                    varid=varid+1
                    iDbio3(iZmortSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ZmortSi_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Mortality (Si), Zooplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimI')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimI(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimI_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Light limitation, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimN')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimN(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimN_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Nitrogen limitation, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimP')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimP(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimP_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Phosphorous limitation, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimSi')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimSi(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimSi_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Silica limitation, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimT')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimT(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimT_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Temperature limitation, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
                CASE ('ilimCTRL')
                  varid=varid-1
                  DO i=1,npmax
                    varid=varid+1
                    iDbio3(ilimCTRL(i))=varid
                    DO ng=1,Ngrids
                      Fscale(varid,ng)=scale
                      Iinfo(1,varid,ng)=gtype
                    END DO
                    WRITE (Vname(1,varid),'(a,i3.3)') 'ilimCTRL_', i
                    WRITE (Vname(2,varid),'(a,i3.3)')                   &
     &                    'Low nut. control factor, Phytoplankton ', i
                    WRITE (Vname(3,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(3)))
                    WRITE (Vname(4,varid),'(a,a)')                      &
     &                    TRIM(Vname(1,varid)), ', scalar, series'
                    WRITE (Vname(5,varid),'(a)')                        &
     &                    TRIM(ADJUSTL(Vinfo(5)))
                  END DO
              END SELECT
            ELSE
              varid=varid-1
            END IF
          END IF
        END DO
        GOTO 40
  30    WRITE (stdout,80) TRIM(ADJUSTL(Vinfo(1)))
        STOP
  40    CLOSE (inp)
!
!-----------------------------------------------------------------------
!  Set passive tracers surface flux metadata. The variable name is the
!  same as the basic tracer but with the _sflux suffix.
!-----------------------------------------------------------------------
!
        DO i=NAT+1,MT
          varid=varid+1
          IF (varid.gt.MV) THEN
            WRITE (stdout,60) MV, varid
            STOP
          END IF
          idTsur(i)=varid
          DO ng=1,Ngrids
            Fscale(varid,ng)=1.0_r8
            Iinfo(1,varid,ng)=r2dvar
          END DO
          WRITE (Vname(1,varid),'(a,a)')                                &
     &          TRIM(ADJUSTL(Vname(1,idTvar(i)))), '_sflux'
          WRITE (Vname(2,varid),'(a,a)')                                &
     &          TRIM(ADJUSTL(Vname(2,idTvar(i)))), ', surface flux'
          WRITE (Vname(3,varid),'(a,1x,a)')                             &
     &          TRIM(ADJUSTL(Vname(3,idTvar(i)))), 'meter second-1'
          WRITE (Vname(4,varid),'(a,a)')                                &
     &          TRIM(Vname(1,varid)), ', scalar, series'
          WRITE (Vname(5,varid),'(a)')                                  &
     &          TRIM(ADJUSTL(Vname(5,idTvar(i))))
        END DO
!
!-----------------------------------------------------------------------
!  Set model state variables indices.
!-----------------------------------------------------------------------
!
        idSvar(isFsur)=idFsur
        idSvar(isUbar)=idUbar
        idSvar(isVbar)=idVbar
        ic=3
        idSvar(isUvel)=idUvel
        idSvar(isVvel)=idVvel
        ic=ic+2
        DO i=1,MT
          idSvar(isTvar(i))=idTvar(i)
          ic=ic+1
        END DO
!
  50    FORMAT (/,' MOD_NCPARAM - Unable to open variable information', &
     &          ' file: ',/,15x,a,/,15x,'Default file is located in',   &
     &          ' source directory.')
  60    FORMAT (/,' MOD_NCPARAM - too small dimension ',                &
     &          'parameter, MV = ',2i5,/,15x,                           &
     &          'change file  mod_ncparam.F  and recompile.')
  70    FORMAT (/,' MOD_NCPARM - Cannot load information for ',         &
     &          'variable: ',a,/,15x,'Need CASE construct for: ',a)
  80    FORMAT (/,' MOD_NCPARM - Error while reading information ',     &
     &          'for variable: ',a)
  90    FORMAT (a,i2.2)
 100    FORMAT (a,a,i2.2)
 110    FORMAT (a)
 120    FORMAT (a,a)
        RETURN
        END SUBROUTINE initialize_ncparam
      END MODULE mod_ncparam
